from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Data.Xml.MsXml
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Variant
E_XML_NOTWF: Int32 = -1072897501
E_XML_NODTD: Int32 = -1072897500
E_XML_INVALID: Int32 = -1072897499
E_XML_BUFFERTOOSMALL: Int32 = -1072897498
XHR_PROP_ONDATA_ALWAYS: UInt32 = 0
XHR_PROP_ONDATA_NEVER: UInt64 = 18446744073709551615
DISPID_XOBJ_MIN: UInt32 = 65536
DISPID_XOBJ_MAX: UInt32 = 131071
DISPID_XOBJ_BASE: UInt32 = 65536
DISPID_XMLELEMENTCOLLECTION: UInt32 = 65536
DISPID_XMLELEMENTCOLLECTION_LENGTH: UInt32 = 65537
DISPID_XMLELEMENTCOLLECTION_NEWENUM: Int32 = -4
DISPID_XMLELEMENTCOLLECTION_ITEM: UInt32 = 65539
DISPID_XMLDOCUMENT: UInt32 = 65636
DISPID_XMLDOCUMENT_ROOT: UInt32 = 65637
DISPID_XMLDOCUMENT_FILESIZE: UInt32 = 65638
DISPID_XMLDOCUMENT_FILEMODIFIEDDATE: UInt32 = 65639
DISPID_XMLDOCUMENT_FILEUPDATEDDATE: UInt32 = 65640
DISPID_XMLDOCUMENT_URL: UInt32 = 65641
DISPID_XMLDOCUMENT_MIMETYPE: UInt32 = 65642
DISPID_XMLDOCUMENT_READYSTATE: UInt32 = 65643
DISPID_XMLDOCUMENT_CREATEELEMENT: UInt32 = 65644
DISPID_XMLDOCUMENT_CHARSET: UInt32 = 65645
DISPID_XMLDOCUMENT_VERSION: UInt32 = 65646
DISPID_XMLDOCUMENT_DOCTYPE: UInt32 = 65647
DISPID_XMLDOCUMENT_DTDURL: UInt32 = 65648
DISPID_XMLDOCUMENT_ASYNC: UInt32 = 65649
DISPID_XMLDOCUMENT_CASEINSENSITIVE: UInt32 = 65650
DISPID_XMLDOCUMENT_BASEURL: UInt32 = 65651
DISPID_XMLDOCUMENT_XML: UInt32 = 65652
DISPID_XMLDOCUMENT_LASTERROR: UInt32 = 65653
DISPID_XMLDOCUMENT_TRIMWHITESPACE: UInt32 = 65654
DISPID_XMLDOCUMENT_COMMIT: UInt32 = 65655
DISPID_XMLELEMENT: UInt32 = 65736
DISPID_XMLELEMENT_TAGNAME: UInt32 = 65737
DISPID_XMLELEMENT_PARENT: UInt32 = 65738
DISPID_XMLELEMENT_SETATTRIBUTE: UInt32 = 65739
DISPID_XMLELEMENT_GETATTRIBUTE: UInt32 = 65740
DISPID_XMLELEMENT_REMOVEATTRIBUTE: UInt32 = 65741
DISPID_XMLELEMENT_CHILDREN: UInt32 = 65742
DISPID_XMLELEMENT_TYPE: UInt32 = 65743
DISPID_XMLELEMENT_TEXT: UInt32 = 65744
DISPID_XMLELEMENT_ADDCHILD: UInt32 = 65745
DISPID_XMLELEMENT_REMOVECHILD: UInt32 = 65746
DISPID_XMLELEMENT_ATTRIBUTES: UInt32 = 65747
DISPID_XMLNOTIFSINK: UInt32 = 65836
DISPID_XMLNOTIFSINK_CHILDADDED: UInt32 = 65837
DISPID_XMLATTRIBUTE: UInt32 = 65936
DISPID_XMLATTRIBUTE_NAME: UInt32 = 65937
DISPID_XMLATTRIBUTE_VALUE: UInt32 = 65938
DISPID_XMLERROR: UInt32 = 65936
DISPID_XMLERROR_REASON: UInt32 = 65937
DISPID_XMLERROR_LINE: UInt32 = 65938
DISPID_XMLERROR_POS: UInt32 = 65939
DISPID_NODE: UInt32 = 66036
DISPID_NODE_NAME: UInt32 = 66037
DISPID_NODE_PARENT: UInt32 = 66038
DISPID_NODE_TYPE: UInt32 = 66039
DISPID_NODE_VALUE: UInt32 = 66040
DISPID_NODE_SETATTRIBUTE: UInt32 = 66041
DISPID_NODE_GETATTRIBUTE: UInt32 = 66042
DISPID_NODE_REMOVEATTRIBUTE: UInt32 = 66043
DISPID_NODE_ATTRIBUTES: UInt32 = 66044
DISPID_NODE_ADD: UInt32 = 66045
DISPID_NODE_REMOVE: UInt32 = 66046
DISPID_NODE_CHILDREN: UInt32 = 66047
DISPID_NODELIST: UInt32 = 66136
DISPID_NODELIST_NEWENUM: UInt32 = 66137
DISPID_NODELIST_NEXT: UInt32 = 66138
DISPID_NODELIST_CURRENT: UInt32 = 66139
DISPID_NODELIST_MOVE: UInt32 = 66140
DISPID_NODELIST_MOVETONODE: UInt32 = 66141
DISPID_NODELIST_LENGTH: UInt32 = 66142
DISPID_NODELIST_ITEM: UInt32 = 66143
DISPID_DOM_BASE: UInt32 = 1
DISPID_DOM_COLLECTION_BASE: UInt32 = 1000000
DISPID_DOM_COLLECTION_MAX: UInt32 = 2999999
DISPID_DOM_NODE: UInt32 = 1
DISPID_DOM_NODE_NODENAME: UInt32 = 2
DISPID_DOM_NODE_NODEVALUE: UInt32 = 3
DISPID_DOM_NODE_NODETYPE: UInt32 = 4
DISPID_DOM_NODE_NODETYPEENUM: UInt32 = 5
DISPID_DOM_NODE_PARENTNODE: UInt32 = 6
DISPID_DOM_NODE_CHILDNODES: UInt32 = 7
DISPID_DOM_NODE_FIRSTCHILD: UInt32 = 8
DISPID_DOM_NODE_LASTCHILD: UInt32 = 9
DISPID_DOM_NODE_PREVIOUSSIBLING: UInt32 = 10
DISPID_DOM_NODE_NEXTSIBLING: UInt32 = 11
DISPID_DOM_NODE_ATTRIBUTES: UInt32 = 12
DISPID_DOM_NODE_INSERTBEFORE: UInt32 = 13
DISPID_DOM_NODE_REPLACECHILD: UInt32 = 14
DISPID_DOM_NODE_REMOVECHILD: UInt32 = 15
DISPID_DOM_NODE_APPENDCHILD: UInt32 = 16
DISPID_DOM_NODE_HASCHILDNODES: UInt32 = 17
DISPID_DOM_NODE_OWNERDOC: UInt32 = 18
DISPID_DOM_NODE_CLONENODE: UInt32 = 19
DISPID_XMLDOM_NODE: UInt32 = 20
DISPID_XMLDOM_NODE_STRINGTYPE: UInt32 = 21
DISPID_XMLDOM_NODE_SPECIFIED: UInt32 = 22
DISPID_XMLDOM_NODE_DEFINITION: UInt32 = 23
DISPID_XMLDOM_NODE_TEXT: UInt32 = 24
DISPID_XMLDOM_NODE_NODETYPEDVALUE: UInt32 = 25
DISPID_XMLDOM_NODE_DATATYPE: UInt32 = 26
DISPID_XMLDOM_NODE_XML: UInt32 = 27
DISPID_XMLDOM_NODE_TRANSFORMNODE: UInt32 = 28
DISPID_XMLDOM_NODE_SELECTNODES: UInt32 = 29
DISPID_XMLDOM_NODE_SELECTSINGLENODE: UInt32 = 30
DISPID_XMLDOM_NODE_PARSED: UInt32 = 31
DISPID_XMLDOM_NODE_NAMESPACE: UInt32 = 32
DISPID_XMLDOM_NODE_PREFIX: UInt32 = 33
DISPID_XMLDOM_NODE_BASENAME: UInt32 = 34
DISPID_XMLDOM_NODE_TRANSFORMNODETOOBJECT: UInt32 = 35
DISPID_XMLDOM_NODE__TOP: UInt32 = 36
DISPID_DOM_DOCUMENT: UInt32 = 37
DISPID_DOM_DOCUMENT_DOCTYPE: UInt32 = 38
DISPID_DOM_DOCUMENT_IMPLEMENTATION: UInt32 = 39
DISPID_DOM_DOCUMENT_DOCUMENTELEMENT: UInt32 = 40
DISPID_DOM_DOCUMENT_CREATEELEMENT: UInt32 = 41
DISPID_DOM_DOCUMENT_CREATEDOCUMENTFRAGMENT: UInt32 = 42
DISPID_DOM_DOCUMENT_CREATETEXTNODE: UInt32 = 43
DISPID_DOM_DOCUMENT_CREATECOMMENT: UInt32 = 44
DISPID_DOM_DOCUMENT_CREATECDATASECTION: UInt32 = 45
DISPID_DOM_DOCUMENT_CREATEPROCESSINGINSTRUCTION: UInt32 = 46
DISPID_DOM_DOCUMENT_CREATEATTRIBUTE: UInt32 = 47
DISPID_DOM_DOCUMENT_CREATEENTITY: UInt32 = 48
DISPID_DOM_DOCUMENT_CREATEENTITYREFERENCE: UInt32 = 49
DISPID_DOM_DOCUMENT_GETELEMENTSBYTAGNAME: UInt32 = 50
DISPID_DOM_DOCUMENT_TOP: UInt32 = 51
DISPID_XMLDOM_DOCUMENT: UInt32 = 52
DISPID_XMLDOM_DOCUMENT_DOCUMENTNODE: UInt32 = 53
DISPID_XMLDOM_DOCUMENT_CREATENODE: UInt32 = 54
DISPID_XMLDOM_DOCUMENT_CREATENODEEX: UInt32 = 55
DISPID_XMLDOM_DOCUMENT_NODEFROMID: UInt32 = 56
DISPID_XMLDOM_DOCUMENT_DOCUMENTNAMESPACES: UInt32 = 57
DISPID_XMLDOM_DOCUMENT_LOAD: UInt32 = 58
DISPID_XMLDOM_DOCUMENT_PARSEERROR: UInt32 = 59
DISPID_XMLDOM_DOCUMENT_URL: UInt32 = 60
DISPID_XMLDOM_DOCUMENT_ASYNC: UInt32 = 61
DISPID_XMLDOM_DOCUMENT_ABORT: UInt32 = 62
DISPID_XMLDOM_DOCUMENT_LOADXML: UInt32 = 63
DISPID_XMLDOM_DOCUMENT_SAVE: UInt32 = 64
DISPID_XMLDOM_DOCUMENT_VALIDATE: UInt32 = 65
DISPID_XMLDOM_DOCUMENT_RESOLVENAMESPACE: UInt32 = 66
DISPID_XMLDOM_DOCUMENT_PRESERVEWHITESPACE: UInt32 = 67
DISPID_XMLDOM_DOCUMENT_ONREADYSTATECHANGE: UInt32 = 68
DISPID_XMLDOM_DOCUMENT_ONDATAAVAILABLE: UInt32 = 69
DISPID_XMLDOM_DOCUMENT_ONTRANSFORMNODE: UInt32 = 70
DISPID_XMLDOM_DOCUMENT__TOP: UInt32 = 71
DISPID_DOM_NODELIST: UInt32 = 72
DISPID_DOM_NODELIST_ITEM: UInt32 = 73
DISPID_DOM_NODELIST_LENGTH: UInt32 = 74
DISPID_XMLDOM_NODELIST: UInt32 = 75
DISPID_XMLDOM_NODELIST_NEXTNODE: UInt32 = 76
DISPID_XMLDOM_NODELIST_RESET: UInt32 = 77
DISPID_XMLDOM_NODELIST_NEWENUM: UInt32 = 78
DISPID_XMLDOM_NODELIST__TOP: UInt32 = 79
DISPID_DOM_NAMEDNODEMAP: UInt32 = 80
DISPID_DOM_NAMEDNODEMAP_GETNAMEDITEM: UInt32 = 83
DISPID_DOM_NAMEDNODEMAP_SETNAMEDITEM: UInt32 = 84
DISPID_DOM_NAMEDNODEMAP_REMOVENAMEDITEM: UInt32 = 85
DISPID_XMLDOM_NAMEDNODEMAP: UInt32 = 86
DISPID_XMLDOM_NAMEDNODEMAP_GETQUALIFIEDITEM: UInt32 = 87
DISPID_XMLDOM_NAMEDNODEMAP_REMOVEQUALIFIEDITEM: UInt32 = 88
DISPID_XMLDOM_NAMEDNODEMAP_NEXTNODE: UInt32 = 89
DISPID_XMLDOM_NAMEDNODEMAP_RESET: UInt32 = 90
DISPID_XMLDOM_NAMEDNODEMAP_NEWENUM: UInt32 = 91
DISPID_XMLDOM_NAMEDNODEMAP__TOP: UInt32 = 92
DISPID_DOM_W3CWRAPPERS: UInt32 = 93
DISPID_DOM_DOCUMENTFRAGMENT: UInt32 = 94
DISPID_DOM_DOCUMENTFRAGMENT__TOP: UInt32 = 95
DISPID_DOM_ELEMENT: UInt32 = 96
DISPID_DOM_ELEMENT_GETTAGNAME: UInt32 = 97
DISPID_DOM_ELEMENT_GETATTRIBUTES: UInt32 = 98
DISPID_DOM_ELEMENT_GETATTRIBUTE: UInt32 = 99
DISPID_DOM_ELEMENT_SETATTRIBUTE: UInt32 = 100
DISPID_DOM_ELEMENT_REMOVEATTRIBUTE: UInt32 = 101
DISPID_DOM_ELEMENT_GETATTRIBUTENODE: UInt32 = 102
DISPID_DOM_ELEMENT_SETATTRIBUTENODE: UInt32 = 103
DISPID_DOM_ELEMENT_REMOVEATTRIBUTENODE: UInt32 = 104
DISPID_DOM_ELEMENT_GETELEMENTSBYTAGNAME: UInt32 = 105
DISPID_DOM_ELEMENT_NORMALIZE: UInt32 = 106
DISPID_DOM_ELEMENT__TOP: UInt32 = 107
DISPID_DOM_DATA: UInt32 = 108
DISPID_DOM_DATA_DATA: UInt32 = 109
DISPID_DOM_DATA_LENGTH: UInt32 = 110
DISPID_DOM_DATA_SUBSTRING: UInt32 = 111
DISPID_DOM_DATA_APPEND: UInt32 = 112
DISPID_DOM_DATA_INSERT: UInt32 = 113
DISPID_DOM_DATA_DELETE: UInt32 = 114
DISPID_DOM_DATA_REPLACE: UInt32 = 115
DISPID_DOM_DATA__TOP: UInt32 = 116
DISPID_DOM_ATTRIBUTE: UInt32 = 117
DISPID_DOM_ATTRIBUTE_GETNAME: UInt32 = 118
DISPID_DOM_ATTRIBUTE_SPECIFIED: UInt32 = 119
DISPID_DOM_ATTRIBUTE_VALUE: UInt32 = 120
DISPID_DOM_ATTRIBUTE__TOP: UInt32 = 121
DISPID_DOM_TEXT: UInt32 = 122
DISPID_DOM_TEXT_SPLITTEXT: UInt32 = 123
DISPID_DOM_TEXT_JOINTEXT: UInt32 = 124
DISPID_DOM_TEXT__TOP: UInt32 = 125
DISPID_DOM_PI: UInt32 = 126
DISPID_DOM_PI_TARGET: UInt32 = 127
DISPID_DOM_PI_DATA: UInt32 = 128
DISPID_DOM_PI__TOP: UInt32 = 129
DISPID_DOM_DOCUMENTTYPE: UInt32 = 130
DISPID_DOM_DOCUMENTTYPE_NAME: UInt32 = 131
DISPID_DOM_DOCUMENTTYPE_ENTITIES: UInt32 = 132
DISPID_DOM_DOCUMENTTYPE_NOTATIONS: UInt32 = 133
DISPID_DOM_DOCUMENTTYPE__TOP: UInt32 = 134
DISPID_DOM_NOTATION: UInt32 = 135
DISPID_DOM_NOTATION_PUBLICID: UInt32 = 136
DISPID_DOM_NOTATION_SYSTEMID: UInt32 = 137
DISPID_DOM_NOTATION__TOP: UInt32 = 138
DISPID_DOM_ENTITY: UInt32 = 139
DISPID_DOM_ENTITY_PUBLICID: UInt32 = 140
DISPID_DOM_ENTITY_SYSTEMID: UInt32 = 141
DISPID_DOM_ENTITY_NOTATIONNAME: UInt32 = 142
DISPID_DOM_ENTITY__TOP: UInt32 = 143
DISPID_DOM_W3CWRAPPERS_TOP: UInt32 = 143
DISPID_DOM_IMPLEMENTATION: UInt32 = 144
DISPID_DOM_IMPLEMENTATION_HASFEATURE: UInt32 = 145
DISPID_DOM_IMPLEMENTATION__TOP: UInt32 = 146
DISPID_DOM__TOP: UInt32 = 176
DISPID_DOM_ERROR: UInt32 = 177
DISPID_DOM_ERROR_ERRORCODE: UInt32 = 178
DISPID_DOM_ERROR_URL: UInt32 = 179
DISPID_DOM_ERROR_REASON: UInt32 = 180
DISPID_DOM_ERROR_SRCTEXT: UInt32 = 181
DISPID_DOM_ERROR_LINE: UInt32 = 182
DISPID_DOM_ERROR_LINEPOS: UInt32 = 183
DISPID_DOM_ERROR_FILEPOS: UInt32 = 184
DISPID_DOM_ERROR__TOP: UInt32 = 185
DISPID_DOM_ERROR2: UInt32 = 186
DISPID_DOM_ERROR2_ALLERRORS: UInt32 = 187
DISPID_DOM_ERROR2_ERRORPARAMETERS: UInt32 = 188
DISPID_DOM_ERROR2_ERRORPARAMETERSCOUNT: UInt32 = 189
DISPID_DOM_ERROR2_ERRORXPATH: UInt32 = 190
DISPID_DOM_ERROR2__TOP: UInt32 = 191
DISPID_DOM_ERRORCOLLECTION: UInt32 = 192
DISPID_DOM_ERRORCOLLECTION_LENGTH: UInt32 = 193
DISPID_DOM_ERRORCOLLECTION_NEXT: UInt32 = 194
DISPID_DOM_ERRORCOLLECTION_RESET: UInt32 = 195
DISPID_DOM_ERRORCOLLECTION__TOP: UInt32 = 196
DISPID_XTLRUNTIME: UInt32 = 186
DISPID_XTLRUNTIME_UNIQUEID: UInt32 = 187
DISPID_XTLRUNTIME_DEPTH: UInt32 = 188
DISPID_XTLRUNTIME_CHILDNUMBER: UInt32 = 189
DISPID_XTLRUNTIME_ANCESTORCHILDNUMBER: UInt32 = 190
DISPID_XTLRUNTIME_ABSOLUTECHILDNUMBER: UInt32 = 191
DISPID_XTLRUNTIME_FORMATINDEX: UInt32 = 192
DISPID_XTLRUNTIME_FORMATNUMBER: UInt32 = 193
DISPID_XTLRUNTIME_FORMATDATE: UInt32 = 194
DISPID_XTLRUNTIME_FORMATTIME: UInt32 = 195
DISPID_XTLRUNTIME__TOP: UInt32 = 196
DISPID_XMLDOMEVENT: UInt32 = 197
DISPID_XMLDOMEVENT_ONREADYSTATECHANGE: Int32 = -609
DISPID_XMLDOMEVENT_ONDATAAVAILABLE: UInt32 = 198
DISPID_XMLDOMEVENT__TOP: UInt32 = 199
DISPID_XMLDOM_DOCUMENT2: UInt32 = 200
DISPID_XMLDOM_DOCUMENT2_NAMESPACES: UInt32 = 201
DISPID_XMLDOM_DOCUMENT2_SCHEMAS: UInt32 = 202
DISPID_XMLDOM_DOCUMENT2_VALIDATE: UInt32 = 203
DISPID_XMLDOM_DOCUMENT2_SETPROPERTY: UInt32 = 204
DISPID_XMLDOM_DOCUMENT2_GETPROPERTY: UInt32 = 205
DISPID_XMLDOM_DOCUMENT2__TOP: UInt32 = 206
DISPID_XMLDOM_DOCUMENT3: UInt32 = 207
DISPID_XMLDOM_DOCUMENT3_VALIDATENODE: UInt32 = 208
DISPID_XMLDOM_DOCUMENT3_IMPORTNODE: UInt32 = 209
DISPID_XMLDOM_DOCUMENT3__TOP: UInt32 = 210
DISPID_XMLDOM_SCHEMACOLLECTION: UInt32 = 2
DISPID_XMLDOM_SCHEMACOLLECTION_ADD: UInt32 = 3
DISPID_XMLDOM_SCHEMACOLLECTION_GET: UInt32 = 4
DISPID_XMLDOM_SCHEMACOLLECTION_REMOVE: UInt32 = 5
DISPID_XMLDOM_SCHEMACOLLECTION_LENGTH: UInt32 = 6
DISPID_XMLDOM_SCHEMACOLLECTION_NAMESPACEURI: UInt32 = 7
DISPID_XMLDOM_SCHEMACOLLECTION_ADDCOLLECTION: UInt32 = 8
DISPID_XMLDOM_SCHEMACOLLECTION__TOP: UInt32 = 9
DISPID_XMLDOM_SELECTION: UInt32 = 80
DISPID_XMLDOM_SELECTION_EXPR: UInt32 = 81
DISPID_XMLDOM_SELECTION_CONTEXT: UInt32 = 82
DISPID_XMLDOM_SELECTION_PEEKNODE: UInt32 = 83
DISPID_XMLDOM_SELECTION_MATCHES: UInt32 = 84
DISPID_XMLDOM_SELECTION_REMOVENEXT: UInt32 = 85
DISPID_XMLDOM_SELECTION_REMOVEALL: UInt32 = 86
DISPID_XMLDOM_SELECTION_CLONE: UInt32 = 87
DISPID_XMLDOM_SELECTION_GETPROPERTY: UInt32 = 88
DISPID_XMLDOM_SELECTION_SETPROPERTY: UInt32 = 89
DISPID_XMLDOM_SELECTION__TOP: UInt32 = 90
DISPID_XMLDOM_TEMPLATE: UInt32 = 1
DISPID_XMLDOM_TEMPLATE_STYLESHEET: UInt32 = 2
DISPID_XMLDOM_TEMPLATE_CREATEPROCESSOR: UInt32 = 3
DISPID_XMLDOM_TEMPLATE__TOP: UInt32 = 4
DISPID_XMLDOM_PROCESSOR: UInt32 = 1
DISPID_XMLDOM_PROCESSOR_INPUT: UInt32 = 2
DISPID_XMLDOM_PROCESSOR_XSLTEMPLATE: UInt32 = 3
DISPID_XMLDOM_PROCESSOR_SETSTARTMODE: UInt32 = 4
DISPID_XMLDOM_PROCESSOR_STARTMODE: UInt32 = 5
DISPID_XMLDOM_PROCESSOR_STARTMODEURI: UInt32 = 6
DISPID_XMLDOM_PROCESSOR_OUTPUT: UInt32 = 7
DISPID_XMLDOM_PROCESSOR_TRANSFORM: UInt32 = 8
DISPID_XMLDOM_PROCESSOR_RESET: UInt32 = 9
DISPID_XMLDOM_PROCESSOR_READYSTATE: UInt32 = 10
DISPID_XMLDOM_PROCESSOR_ADDPARAMETER: UInt32 = 11
DISPID_XMLDOM_PROCESSOR_ADDOBJECT: UInt32 = 12
DISPID_XMLDOM_PROCESSOR_STYLESHEET: UInt32 = 13
DISPID_XMLDOM_PROCESSOR__TOP: UInt32 = 14
DISPID_XMLDSO: UInt32 = 65536
DISPID_XMLDSO_DOCUMENT: UInt32 = 65537
DISPID_XMLDSO_JAVADSOCOMPATIBLE: UInt32 = 65538
DISPID_SAX_XMLREADER__MIN: UInt32 = 1281
DISPID_SAX_XMLREADER__MAX: UInt32 = 65536
DISPID_SAX_XMLREADER__BASE: UInt32 = 1281
DISPID_SAX_XMLREADER: UInt32 = 1281
DISPID_SAX_XMLREADER_GETFEATURE: UInt32 = 1282
DISPID_SAX_XMLREADER_PUTFEATURE: UInt32 = 1283
DISPID_SAX_XMLREADER_GETPROPERTY: UInt32 = 1284
DISPID_SAX_XMLREADER_PUTPROPERTY: UInt32 = 1285
DISPID_SAX_XMLREADER_ENTITYRESOLVER: UInt32 = 1286
DISPID_SAX_XMLREADER_CONTENTHANDLER: UInt32 = 1287
DISPID_SAX_XMLREADER_DTDHANDLER: UInt32 = 1288
DISPID_SAX_XMLREADER_ERRORHANDLER: UInt32 = 1289
DISPID_SAX_XMLREADER_BASEURL: UInt32 = 1290
DISPID_SAX_XMLREADER_SECUREBASEURL: UInt32 = 1291
DISPID_SAX_XMLREADER_PARSE: UInt32 = 1292
DISPID_SAX_XMLREADER_PARSEURL: UInt32 = 1293
DISPID_SAX_XMLREADER_PARENT: UInt32 = 1294
DISPID_SAX_XMLREADER__TOP: UInt32 = 1295
DISPID_SAX_XMLFILTER__BASE: UInt32 = 1296
DISPID_SAX_XMLFILTER: UInt32 = 1296
DISPID_SAX_XMLFILTER_GETFEATURE: UInt32 = 1297
DISPID_SAX_XMLFILTER_PUTFEATURE: UInt32 = 1298
DISPID_SAX_XMLFILTER_GETPROPERTY: UInt32 = 1299
DISPID_SAX_XMLFILTER_PUTPROPERTY: UInt32 = 1300
DISPID_SAX_XMLFILTER_ENTITYRESOLVER: UInt32 = 1301
DISPID_SAX_XMLFILTER_CONTENTHANDLER: UInt32 = 1302
DISPID_SAX_XMLFILTER_DTDHANDLER: UInt32 = 1303
DISPID_SAX_XMLFILTER_ERRORHANDLER: UInt32 = 1304
DISPID_SAX_XMLFILTER_BASEURL: UInt32 = 1305
DISPID_SAX_XMLFILTER_SECUREBASEURL: UInt32 = 1306
DISPID_SAX_XMLFILTER_PARSE: UInt32 = 1307
DISPID_SAX_XMLFILTER_PARSEURL: UInt32 = 1308
DISPID_SAX_XMLFILTER_PARENT: UInt32 = 1309
DISPID_SAX_XMLFILTER__TOP: UInt32 = 1311
DISPID_SAX_LOCATOR__BASE: UInt32 = 1312
DISPID_SAX_LOCATOR: UInt32 = 1312
DISPID_SAX_LOCATOR_COLUMNNUMBER: UInt32 = 1313
DISPID_SAX_LOCATOR_LINENUMBER: UInt32 = 1314
DISPID_SAX_LOCATOR_PUBLICID: UInt32 = 1315
DISPID_SAX_LOCATOR_SYSTEMID: UInt32 = 1316
DISPID_SAX_LOCATOR__TOP: UInt32 = 1317
DISPID_SAX_ENTITYRESOLVER__BASE: UInt32 = 1318
DISPID_SAX_ENTITYRESOLVER: UInt32 = 1318
DISPID_SAX_ENTITYRESOLVER_RESOLVEENTITY: UInt32 = 1319
DISPID_SAX_ENTITYRESOLVER__TOP: UInt32 = 1320
DISPID_SAX_CONTENTHANDLER__BASE: UInt32 = 1321
DISPID_SAX_CONTENTHANDLER: UInt32 = 1321
DISPID_SAX_CONTENTHANDLER_DOCUMENTLOCATOR: UInt32 = 1322
DISPID_SAX_CONTENTHANDLER_STARTDOCUMENT: UInt32 = 1323
DISPID_SAX_CONTENTHANDLER_ENDDOCUMENT: UInt32 = 1324
DISPID_SAX_CONTENTHANDLER_STARTPREFIXMAPPING: UInt32 = 1325
DISPID_SAX_CONTENTHANDLER_ENDPREFIXMAPPING: UInt32 = 1326
DISPID_SAX_CONTENTHANDLER_STARTELEMENT: UInt32 = 1327
DISPID_SAX_CONTENTHANDLER_ENDELEMENT: UInt32 = 1328
DISPID_SAX_CONTENTHANDLER_CHARACTERS: UInt32 = 1329
DISPID_SAX_CONTENTHANDLER_IGNORABLEWHITESPACE: UInt32 = 1330
DISPID_SAX_CONTENTHANDLER_PROCESSINGINSTRUCTION: UInt32 = 1331
DISPID_SAX_CONTENTHANDLER_SKIPPEDENTITY: UInt32 = 1332
DISPID_SAX_CONTENTHANDLER__TOP: UInt32 = 1333
DISPID_SAX_DTDHANDLER__BASE: UInt32 = 1334
DISPID_SAX_DTDHANDLER: UInt32 = 1334
DISPID_SAX_DTDHANDLER_NOTATIONDECL: UInt32 = 1335
DISPID_SAX_DTDHANDLER_UNPARSEDENTITYDECL: UInt32 = 1336
DISPID_SAX_DTDHANDLER__TOP: UInt32 = 1337
DISPID_SAX_ERRORHANDLER__BASE: UInt32 = 1338
DISPID_SAX_ERRORHANDLER: UInt32 = 1338
DISPID_SAX_ERRORHANDLER_ERROR: UInt32 = 1339
DISPID_SAX_ERRORHANDLER_FATALERROR: UInt32 = 1340
DISPID_SAX_ERRORHANDLER_IGNORABLEWARNING: UInt32 = 1341
DISPID_SAX_ERRORHANDLER__TOP: UInt32 = 1342
DISPID_SAX_ATTRIBUTES__BASE: UInt32 = 1343
DISPID_SAX_ATTRIBUTES: UInt32 = 1343
DISPID_SAX_ATTRIBUTES_LENGTH: UInt32 = 1344
DISPID_SAX_ATTRIBUTES_GETURI: UInt32 = 1345
DISPID_SAX_ATTRIBUTES_GETLOCALNAME: UInt32 = 1346
DISPID_SAX_ATTRIBUTES_GETQNAME: UInt32 = 1347
DISPID_SAX_ATTRIBUTES_GETINDEXFROMNAME: UInt32 = 1348
DISPID_SAX_ATTRIBUTES_GETINDEXFROMQNAME: UInt32 = 1349
DISPID_SAX_ATTRIBUTES_GETTYPE: UInt32 = 1350
DISPID_SAX_ATTRIBUTES_GETTYPEFROMNAME: UInt32 = 1351
DISPID_SAX_ATTRIBUTES_GETTYPEFROMQNAME: UInt32 = 1352
DISPID_SAX_ATTRIBUTES_GETVALUE: UInt32 = 1353
DISPID_SAX_ATTRIBUTES_GETVALUEFROMNAME: UInt32 = 1354
DISPID_SAX_ATTRIBUTES_GETVALUEFROMQNAME: UInt32 = 1355
DISPID_SAX_ATTRIBUTES__TOP: UInt32 = 1356
DISPID_SAX_LEXICALHANDLER__BASE: UInt32 = 1357
DISPID_SAX_LEXICALHANDLER: UInt32 = 1357
DISPID_SAX_LEXICALHANDLER_STARTDTD: UInt32 = 1358
DISPID_SAX_LEXICALHANDLER_ENDDTD: UInt32 = 1359
DISPID_SAX_LEXICALHANDLER_STARTENTITY: UInt32 = 1360
DISPID_SAX_LEXICALHANDLER_ENDENTITY: UInt32 = 1361
DISPID_SAX_LEXICALHANDLER_STARTCDATA: UInt32 = 1362
DISPID_SAX_LEXICALHANDLER_ENDCDATA: UInt32 = 1363
DISPID_SAX_LEXICALHANDLER_COMMENT: UInt32 = 1364
DISPID_SAX_LEXICALHANDLER__TOP: UInt32 = 1365
DISPID_SAX_DECLHANDLER__BASE: UInt32 = 1366
DISPID_SAX_DECLHANDLER: UInt32 = 1366
DISPID_SAX_DECLHANDLER_ELEMENTDECL: UInt32 = 1367
DISPID_SAX_DECLHANDLER_ATTRIBUTEDECL: UInt32 = 1368
DISPID_SAX_DECLHANDLER_INTERNALENTITYDECL: UInt32 = 1369
DISPID_SAX_DECLHANDLER_EXTERNALENTITYDECL: UInt32 = 1370
DISPID_SAX_DECLHANDLER__TOP: UInt32 = 1371
DISPID_MX_ATTRIBUTES__BASE: UInt32 = 1372
DISPID_MX_ATTRIBUTES: UInt32 = 1372
DISPID_MX_ATTRIBUTES_ADDATTRIBUTE: UInt32 = 1373
DISPID_MX_ATTRIBUTES_CLEAR: UInt32 = 1374
DISPID_MX_ATTRIBUTES_REMOVEATTRIBUTE: UInt32 = 1375
DISPID_MX_ATTRIBUTES_SETATTRIBUTE: UInt32 = 1376
DISPID_MX_ATTRIBUTES_SETATTRIBUTES: UInt32 = 1377
DISPID_MX_ATTRIBUTES_SETLOCALNAME: UInt32 = 1378
DISPID_MX_ATTRIBUTES_SETQNAME: UInt32 = 1379
DISPID_MX_ATTRIBUTES_SETTYPE: UInt32 = 1380
DISPID_MX_ATTRIBUTES_SETURI: UInt32 = 1381
DISPID_MX_ATTRIBUTES_SETVALUE: UInt32 = 1382
DISPID_MX_ATTRIBUTES_ADDATTRIBUTEFROMINDEX: UInt32 = 1383
DISPID_MX_ATTRIBUTES__TOP: UInt32 = 1383
DISPID_MX_WRITER__BASE: UInt32 = 1384
DISPID_MX_WRITER: UInt32 = 1384
DISPID_MX_WRITER_OUTPUT: UInt32 = 1385
DISPID_MX_WRITER_DESTINATION: UInt32 = 1386
DISPID_MX_WRITER_ENCODING: UInt32 = 1387
DISPID_MX_WRITER_BYTEORDERMARK: UInt32 = 1388
DISPID_MX_WRITER_INDENT: UInt32 = 1389
DISPID_MX_WRITER_STANDALONE: UInt32 = 1390
DISPID_MX_WRITER_OMITXMLDECLARATION: UInt32 = 1391
DISPID_MX_WRITER_VERSION: UInt32 = 1392
DISPID_MX_WRITER_DISABLEOUTPUTESCAPING: UInt32 = 1393
DISPID_MX_WRITER_FLUSH: UInt32 = 1394
DISPID_MX_WRITER_RESET: UInt32 = 1395
DISPID_MX_WRITER__TOP: UInt32 = 1396
DISPID_MX_READER_CONTROL__BASE: UInt32 = 1397
DISPID_MX_READER_CONTROL: UInt32 = 1397
DISPID_MX_READER_CONTROL_ABORT: UInt32 = 1398
DISPID_MX_READER_CONTROL_RESUME: UInt32 = 1399
DISPID_MX_READER_CONTROL_SUSPEND: UInt32 = 1400
DISPID_MX_READER_CONTROL__TOP: UInt32 = 1401
DISPID_MX_SCHEMADECLHANDLER__BASE: UInt32 = 1402
DISPID_MX_SCHEMADECLHANDLER: UInt32 = 1402
DISPID_MX_SCHEMADECLHANDLER_SCHEMAELEMENTDECL: UInt32 = 1403
DISPID_MX_SCHEMADECLHANDLER__TOP: UInt32 = 1404
DISPID_MX_NSMGR__BASE: UInt32 = 1405
DISPID_MX_NSMGR: UInt32 = 1405
DISPID_MX_NSMGR_ALLOWOVERRIDE: UInt32 = 1406
DISPID_MX_NSMGR_RESET: UInt32 = 1407
DISPID_MX_NSMGR_PUSHCONTEXT: UInt32 = 1408
DISPID_MX_NSMGR_PUSHNODECONTEXT: UInt32 = 1409
DISPID_MX_NSMGR_POPCONTEXT: UInt32 = 1410
DISPID_MX_NSMGR_DECLAREPREFIX: UInt32 = 1411
DISPID_MX_NSMGR_GETDECLAREDPREFIXES: UInt32 = 1412
DISPID_MX_NSMGR_GETPREFIXES: UInt32 = 1413
DISPID_MX_NSMGR_GETURI: UInt32 = 1414
DISPID_MX_NSMGR_GETURIFROMNODE: UInt32 = 1415
DISPID_MX_NSMGR_LENGTH: UInt32 = 1416
DISPID_MX_NSMGR__TOP: UInt32 = 1417
DISPID_MXXML_FILTER__BASE: UInt32 = 1418
DISPID_MXXML_FILTER: UInt32 = 1418
DISPID_MXXML_FILTER_CONTENTHANDLER: UInt32 = 1419
DISPID_MXXML_FILTER_DTDHANDLER: UInt32 = 1420
DISPID_MXXML_FILTER_ENTITYRESOLVER: UInt32 = 1421
DISPID_MXXML_FILTER_ERRORHANDLER: UInt32 = 1422
DISPID_MXXML_FILTER_GETFEATURE: UInt32 = 1423
DISPID_MXXML_FILTER_GETPROPERTY: UInt32 = 1424
DISPID_MXXML_FILTER_PUTFEATURE: UInt32 = 1425
DISPID_MXXML_FILTER_PUTPROPERTY: UInt32 = 1426
DISPID_MXXML_FILTER__TOP: UInt32 = 1427
DISPID_SOM: UInt32 = 1418
DISPID_SOM_VALIDATE: UInt32 = 1419
DISPID_SOM_VALIDATEONLOAD: UInt32 = 1420
DISPID_SOM_GETSCHEMA: UInt32 = 1421
DISPID_SOM_GETDECLARATION: UInt32 = 1422
DISPID_SOM_ITEMBYNAME: UInt32 = 1423
DISPID_SOM_ITEMBYQNAME: UInt32 = 1424
DISPID_SOM_ANYATTRIBUTE: UInt32 = 1425
DISPID_SOM_ATTRIBUTEGROUPS: UInt32 = 1426
DISPID_SOM_ATTRIBUTES: UInt32 = 1427
DISPID_SOM_BASETYPES: UInt32 = 1428
DISPID_SOM_CONTENTMODEL: UInt32 = 1429
DISPID_SOM_CONTENTTYPE: UInt32 = 1430
DISPID_SOM_DEFAULTVALUE: UInt32 = 1431
DISPID_SOM_DERIVEDBY: UInt32 = 1432
DISPID_SOM_DISALLOWED: UInt32 = 1433
DISPID_SOM_ELEMENTS: UInt32 = 1434
DISPID_SOM_ENUMERATION: UInt32 = 1435
DISPID_SOM_FIELDS: UInt32 = 1436
DISPID_SOM_FINAL: UInt32 = 1437
DISPID_SOM_FIXEDVALUE: UInt32 = 1438
DISPID_SOM_FRACTIONDIGITS: UInt32 = 1439
DISPID_SOM_ID: UInt32 = 1440
DISPID_SOM_IDCONSTRAINTS: UInt32 = 1441
DISPID_SOM_ISABSTRACT: UInt32 = 1442
DISPID_SOM_ISNILLABLE: UInt32 = 1443
DISPID_SOM_ISREFERENCE: UInt32 = 1444
DISPID_SOM_ISVALID: UInt32 = 1445
DISPID_SOM_ITEMTYPE: UInt32 = 1446
DISPID_SOM_LENGTH: UInt32 = 1447
DISPID_SOM_MAXEXCLUSIVE: UInt32 = 1448
DISPID_SOM_MAXINCLUSIVE: UInt32 = 1449
DISPID_SOM_MAXLENGTH: UInt32 = 1450
DISPID_SOM_MAXOCCURS: UInt32 = 1451
DISPID_SOM_MINEXCLUSIVE: UInt32 = 1452
DISPID_SOM_MININCLUSIVE: UInt32 = 1453
DISPID_SOM_MINLENGTH: UInt32 = 1454
DISPID_SOM_MINOCCURS: UInt32 = 1455
DISPID_SOM_MODELGROUPS: UInt32 = 1456
DISPID_SOM_NAME: UInt32 = 1457
DISPID_SOM_NAMESPACES: UInt32 = 1458
DISPID_SOM_NAMESPACEURI: UInt32 = 1459
DISPID_SOM_NOTATIONS: UInt32 = 1460
DISPID_SOM_PARTICLES: UInt32 = 1461
DISPID_SOM_PATTERNS: UInt32 = 1462
DISPID_SOM_PROCESSCONTENTS: UInt32 = 1463
DISPID_SOM_PROHIBITED: UInt32 = 1464
DISPID_SOM_PUBLICIDENTIFIER: UInt32 = 1465
DISPID_SOM_REFERENCEDKEY: UInt32 = 1466
DISPID_SOM_SCHEMA: UInt32 = 1467
DISPID_SOM_SCHEMALOCATIONS: UInt32 = 1468
DISPID_SOM_SCOPE: UInt32 = 1469
DISPID_SOM_SELECTOR: UInt32 = 1470
DISPID_SOM_SUBSTITUTIONGROUP: UInt32 = 1471
DISPID_SOM_EXCLUSIONS: UInt32 = 1472
DISPID_SOM_SYSTEMIDENTIFIER: UInt32 = 1473
DISPID_SOM_TARGETNAMESPACE: UInt32 = 1474
DISPID_SOM_TOTALDIGITS: UInt32 = 1475
DISPID_SOM_TYPE: UInt32 = 1476
DISPID_SOM_TYPES: UInt32 = 1477
DISPID_SOM_UNHANDLEDATTRS: UInt32 = 1478
DISPID_SOM_USE: UInt32 = 1479
DISPID_SOM_VARIETY: UInt32 = 1480
DISPID_SOM_VERSION: UInt32 = 1481
DISPID_SOM_WHITESPACE: UInt32 = 1482
DISPID_SOM_WRITEANNOTATION: UInt32 = 1483
DISPID_SOM_TOP: UInt32 = 1484
DISPID_XMLDSIG: UInt32 = 1
DISPID_XMLDSIG_CREATEKEYFROMCSP: UInt32 = 1
DISPID_XMLDSIG_CREATEKEYFROMHMACSECRET: UInt32 = 2
DISPID_XMLDSIG_CREATEKEYFROMNODE: UInt32 = 3
DISPID_XMLDSIG_CREATESAXPROXY: UInt32 = 4
DISPID_XMLDSIG_GETVERIFYINGCERTIFICATE: UInt32 = 5
DISPID_XMLDSIG_SETREFERENCEDATA: UInt32 = 6
DISPID_XMLDSIG_SIGN: UInt32 = 7
DISPID_XMLDSIG_SIGNATURE: UInt32 = 8
DISPID_XMLDSIG_STORE: UInt32 = 9
DISPID_XMLDSIG_VERIFY: UInt32 = 10
DOMDocument = Guid('{2933bf90-7b36-11d2-b20e-00c04f983e60}')
DOMDocument60 = Guid('{88d96a05-f192-11d4-a65f-0040963251e5}')
DOMFreeThreadedDocument = Guid('{2933bf91-7b36-11d2-b20e-00c04f983e60}')
DOMNodeType = Int32
NODE_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 0
NODE_ELEMENT: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 1
NODE_ATTRIBUTE: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 2
NODE_TEXT: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 3
NODE_CDATA_SECTION: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 4
NODE_ENTITY_REFERENCE: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 5
NODE_ENTITY: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 6
NODE_PROCESSING_INSTRUCTION: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 7
NODE_COMMENT: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 8
NODE_DOCUMENT: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 9
NODE_DOCUMENT_TYPE: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 10
NODE_DOCUMENT_FRAGMENT: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 11
NODE_NOTATION: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType = 12
FreeThreadedDOMDocument60 = Guid('{88d96a06-f192-11d4-a65f-0040963251e5}')
FreeThreadedXMLHTTP60 = Guid('{88d96a09-f192-11d4-a65f-0040963251e5}')
class IMXAttributes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f10d27cc-3ec0-415c-8ed8-77ab1c5e7262}')
    @commethod(7)
    def addAttribute(self, strURI: win32more.Windows.Win32.Foundation.BSTR, strLocalName: win32more.Windows.Win32.Foundation.BSTR, strQName: win32more.Windows.Win32.Foundation.BSTR, strType: win32more.Windows.Win32.Foundation.BSTR, strValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def addAttributeFromIndex(self, varAtts: win32more.Windows.Win32.System.Variant.VARIANT, nIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def removeAttribute(self, nIndex: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def setAttribute(self, nIndex: Int32, strURI: win32more.Windows.Win32.Foundation.BSTR, strLocalName: win32more.Windows.Win32.Foundation.BSTR, strQName: win32more.Windows.Win32.Foundation.BSTR, strType: win32more.Windows.Win32.Foundation.BSTR, strValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def setAttributes(self, varAtts: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def setLocalName(self, nIndex: Int32, strLocalName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def setQName(self, nIndex: Int32, strQName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def setType(self, nIndex: Int32, strType: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def setURI(self, nIndex: Int32, strURI: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def setValue(self, nIndex: Int32, strValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMXNamespaceManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c90352f6-643c-4fbc-bb23-e996eb2d51fd}')
    @commethod(3)
    def putAllowOverride(self, fOverride: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def getAllowOverride(self, fOverride: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def pushContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def pushNodeContext(self, contextNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, fDeep: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def popContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def declarePrefix(self, prefix: win32more.Windows.Win32.Foundation.PWSTR, namespaceURI: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getDeclaredPrefix(self, nIndex: Int32, pwchPrefix: win32more.Windows.Win32.Foundation.PWSTR, pcchPrefix: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getPrefix(self, pwszNamespaceURI: win32more.Windows.Win32.Foundation.PWSTR, nIndex: Int32, pwchPrefix: win32more.Windows.Win32.Foundation.PWSTR, pcchPrefix: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def getURI(self, pwchPrefix: win32more.Windows.Win32.Foundation.PWSTR, pContextNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, pwchUri: win32more.Windows.Win32.Foundation.PWSTR, pcchUri: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMXNamespacePrefixes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c90352f4-643c-4fbc-bb23-e996eb2d51fd}')
    @commethod(7)
    def get_item(self, index: Int32, prefix: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, length: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__newEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMXReaderControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{808f4e35-8d5a-4fbe-8466-33a41279ed30}')
    @commethod(7)
    def abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def suspend(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMXSchemaDeclHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{fa4bb38c-faf9-4cca-9302-d1dd0fe520db}')
    @commethod(7)
    def schemaElementDecl(self, oSchemaElement: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMXWriter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{4d7ff4ba-1565-4ea8-94e1-6e724a46f98d}')
    @commethod(7)
    def put_output(self, varDestination: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_output(self, varDestination: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_encoding(self, strEncoding: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_encoding(self, strEncoding: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_byteOrderMark(self, fWriteByteOrderMark: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_byteOrderMark(self, fWriteByteOrderMark: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_indent(self, fIndentMode: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_indent(self, fIndentMode: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_standalone(self, fValue: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_standalone(self, fValue: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def put_omitXMLDeclaration(self, fValue: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_omitXMLDeclaration(self, fValue: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def put_version(self, strVersion: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_version(self, strVersion: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_disableOutputEscaping(self, fValue: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_disableOutputEscaping(self, fValue: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def flush(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMXXMLFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c90352f7-643c-4fbc-bb23-e996eb2d51fd}')
    @commethod(7)
    def getFeature(self, strName: win32more.Windows.Win32.Foundation.BSTR, fValue: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def putFeature(self, strName: win32more.Windows.Win32.Foundation.BSTR, fValue: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getProperty(self, strName: win32more.Windows.Win32.Foundation.BSTR, varValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def putProperty(self, strName: win32more.Windows.Win32.Foundation.BSTR, varValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_entityResolver(self, oResolver: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def putref_entityResolver(self, oResolver: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_contentHandler(self, oHandler: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def putref_contentHandler(self, oHandler: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_dtdHandler(self, oHandler: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def putref_dtdHandler(self, oHandler: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_errorHandler(self, oHandler: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def putref_errorHandler(self, oHandler: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXAttributes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f078abe1-45d2-4832-91ea-4466ce2f25c9}')
    @commethod(3)
    def getLength(self, pnLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def getURI(self, nIndex: Int32, ppwchUri: POINTER(POINTER(UInt16)), pcchUri: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def getLocalName(self, nIndex: Int32, ppwchLocalName: POINTER(POINTER(UInt16)), pcchLocalName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def getQName(self, nIndex: Int32, ppwchQName: POINTER(POINTER(UInt16)), pcchQName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def getName(self, nIndex: Int32, ppwchUri: POINTER(POINTER(UInt16)), pcchUri: POINTER(Int32), ppwchLocalName: POINTER(POINTER(UInt16)), pcchLocalName: POINTER(Int32), ppwchQName: POINTER(POINTER(UInt16)), pcchQName: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getIndexFromName(self, pwchUri: win32more.Windows.Win32.Foundation.PWSTR, cchUri: Int32, pwchLocalName: win32more.Windows.Win32.Foundation.PWSTR, cchLocalName: Int32, pnIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getIndexFromQName(self, pwchQName: win32more.Windows.Win32.Foundation.PWSTR, cchQName: Int32, pnIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getType(self, nIndex: Int32, ppwchType: POINTER(POINTER(UInt16)), pcchType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getTypeFromName(self, pwchUri: win32more.Windows.Win32.Foundation.PWSTR, cchUri: Int32, pwchLocalName: win32more.Windows.Win32.Foundation.PWSTR, cchLocalName: Int32, ppwchType: POINTER(POINTER(UInt16)), pcchType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def getTypeFromQName(self, pwchQName: win32more.Windows.Win32.Foundation.PWSTR, cchQName: Int32, ppwchType: POINTER(POINTER(UInt16)), pcchType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def getValue(self, nIndex: Int32, ppwchValue: POINTER(POINTER(UInt16)), pcchValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def getValueFromName(self, pwchUri: win32more.Windows.Win32.Foundation.PWSTR, cchUri: Int32, pwchLocalName: win32more.Windows.Win32.Foundation.PWSTR, cchLocalName: Int32, ppwchValue: POINTER(POINTER(UInt16)), pcchValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def getValueFromQName(self, pwchQName: win32more.Windows.Win32.Foundation.PWSTR, cchQName: Int32, ppwchValue: POINTER(POINTER(UInt16)), pcchValue: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXContentHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1545cdfa-9e4e-4497-a8a4-2bf7d0112c44}')
    @commethod(3)
    def putDocumentLocator(self, pLocator: win32more.Windows.Win32.Data.Xml.MsXml.ISAXLocator) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def startDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def endDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def startPrefixMapping(self, pwchPrefix: win32more.Windows.Win32.Foundation.PWSTR, cchPrefix: Int32, pwchUri: win32more.Windows.Win32.Foundation.PWSTR, cchUri: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def endPrefixMapping(self, pwchPrefix: win32more.Windows.Win32.Foundation.PWSTR, cchPrefix: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def startElement(self, pwchNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR, cchNamespaceUri: Int32, pwchLocalName: win32more.Windows.Win32.Foundation.PWSTR, cchLocalName: Int32, pwchQName: win32more.Windows.Win32.Foundation.PWSTR, cchQName: Int32, pAttributes: win32more.Windows.Win32.Data.Xml.MsXml.ISAXAttributes) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def endElement(self, pwchNamespaceUri: win32more.Windows.Win32.Foundation.PWSTR, cchNamespaceUri: Int32, pwchLocalName: win32more.Windows.Win32.Foundation.PWSTR, cchLocalName: Int32, pwchQName: win32more.Windows.Win32.Foundation.PWSTR, cchQName: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def characters(self, pwchChars: win32more.Windows.Win32.Foundation.PWSTR, cchChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def ignorableWhitespace(self, pwchChars: win32more.Windows.Win32.Foundation.PWSTR, cchChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def processingInstruction(self, pwchTarget: win32more.Windows.Win32.Foundation.PWSTR, cchTarget: Int32, pwchData: win32more.Windows.Win32.Foundation.PWSTR, cchData: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def skippedEntity(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXDTDHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e15c1baf-afb3-4d60-8c36-19a8c45defed}')
    @commethod(3)
    def notationDecl(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, pwchPublicId: win32more.Windows.Win32.Foundation.PWSTR, cchPublicId: Int32, pwchSystemId: win32more.Windows.Win32.Foundation.PWSTR, cchSystemId: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def unparsedEntityDecl(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, pwchPublicId: win32more.Windows.Win32.Foundation.PWSTR, cchPublicId: Int32, pwchSystemId: win32more.Windows.Win32.Foundation.PWSTR, cchSystemId: Int32, pwchNotationName: win32more.Windows.Win32.Foundation.PWSTR, cchNotationName: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXDeclHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{862629ac-771a-47b2-8337-4e6843c1be90}')
    @commethod(3)
    def elementDecl(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, pwchModel: win32more.Windows.Win32.Foundation.PWSTR, cchModel: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def attributeDecl(self, pwchElementName: win32more.Windows.Win32.Foundation.PWSTR, cchElementName: Int32, pwchAttributeName: win32more.Windows.Win32.Foundation.PWSTR, cchAttributeName: Int32, pwchType: win32more.Windows.Win32.Foundation.PWSTR, cchType: Int32, pwchValueDefault: win32more.Windows.Win32.Foundation.PWSTR, cchValueDefault: Int32, pwchValue: win32more.Windows.Win32.Foundation.PWSTR, cchValue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def internalEntityDecl(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, pwchValue: win32more.Windows.Win32.Foundation.PWSTR, cchValue: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def externalEntityDecl(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, pwchPublicId: win32more.Windows.Win32.Foundation.PWSTR, cchPublicId: Int32, pwchSystemId: win32more.Windows.Win32.Foundation.PWSTR, cchSystemId: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXEntityResolver(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{99bca7bd-e8c4-4d5f-a0cf-6d907901ff07}')
    @commethod(3)
    def resolveEntity(self, pwchPublicId: win32more.Windows.Win32.Foundation.PWSTR, pwchSystemId: win32more.Windows.Win32.Foundation.PWSTR, pvarInput: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXErrorHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a60511c4-ccf5-479e-98a3-dc8dc545b7d0}')
    @commethod(3)
    def error(self, pLocator: win32more.Windows.Win32.Data.Xml.MsXml.ISAXLocator, pwchErrorMessage: win32more.Windows.Win32.Foundation.PWSTR, hrErrorCode: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def fatalError(self, pLocator: win32more.Windows.Win32.Data.Xml.MsXml.ISAXLocator, pwchErrorMessage: win32more.Windows.Win32.Foundation.PWSTR, hrErrorCode: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def ignorableWarning(self, pLocator: win32more.Windows.Win32.Data.Xml.MsXml.ISAXLocator, pwchErrorMessage: win32more.Windows.Win32.Foundation.PWSTR, hrErrorCode: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXLexicalHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7f85d5f5-47a8-4497-bda5-84ba04819ea6}')
    @commethod(3)
    def startDTD(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32, pwchPublicId: win32more.Windows.Win32.Foundation.PWSTR, cchPublicId: Int32, pwchSystemId: win32more.Windows.Win32.Foundation.PWSTR, cchSystemId: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def endDTD(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def startEntity(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def endEntity(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, cchName: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def startCDATA(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def endCDATA(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def comment(self, pwchChars: win32more.Windows.Win32.Foundation.PWSTR, cchChars: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXLocator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9b7e472a-0de4-4640-bff3-84d38a051c31}')
    @commethod(3)
    def getColumnNumber(self, pnColumn: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def getLineNumber(self, pnLine: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def getPublicId(self, ppwchPublicId: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def getSystemId(self, ppwchSystemId: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXXMLFilter(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISAXXMLReader
    _iid_ = Guid('{70409222-ca09-4475-acb8-40312fe8d145}')
    @commethod(21)
    def getParent(self, ppReader: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISAXXMLReader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def putParent(self, pReader: win32more.Windows.Win32.Data.Xml.MsXml.ISAXXMLReader) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISAXXMLReader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a4f96ed0-f829-476e-81c0-cdc7bd2a0802}')
    @commethod(3)
    def getFeature(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, pvfValue: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def putFeature(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, vfValue: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def getProperty(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, pvarValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def putProperty(self, pwchName: win32more.Windows.Win32.Foundation.PWSTR, varValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def getEntityResolver(self, ppResolver: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISAXEntityResolver)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def putEntityResolver(self, pResolver: win32more.Windows.Win32.Data.Xml.MsXml.ISAXEntityResolver) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getContentHandler(self, ppHandler: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISAXContentHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def putContentHandler(self, pHandler: win32more.Windows.Win32.Data.Xml.MsXml.ISAXContentHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getDTDHandler(self, ppHandler: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISAXDTDHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def putDTDHandler(self, pHandler: win32more.Windows.Win32.Data.Xml.MsXml.ISAXDTDHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def getErrorHandler(self, ppHandler: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISAXErrorHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def putErrorHandler(self, pHandler: win32more.Windows.Win32.Data.Xml.MsXml.ISAXErrorHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def getBaseURL(self, ppwchBaseUrl: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def putBaseURL(self, pwchBaseUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def getSecureBaseURL(self, ppwchSecureBaseUrl: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def putSecureBaseURL(self, pwchSecureBaseUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def parse(self, varInput: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def parseURL(self, pwchUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchema(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08b4-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_targetNamespace(self, targetNamespace: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_version(self, version: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_types(self, types: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_elements(self, elements: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_attributes(self, attributes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_attributeGroups(self, attributeGroups: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_modelGroups(self, modelGroups: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_notations(self, notations: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_schemaLocations(self, schemaLocations: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaAny(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaParticle
    _iid_ = Guid('{50ea08bc-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(16)
    def get_namespaces(self, namespaces: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_processContents(self, processContents: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaAttribute(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08b6-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_type(self, type: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_scope(self, scope: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaComplexType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_defaultValue(self, defaultValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_fixedValue(self, fixedValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_use(self, use: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAUSE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_isReference(self, reference: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaAttributeGroup(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08ba-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_anyAttribute(self, anyAttribute: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaAny)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_attributes(self, attributes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaComplexType(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaType
    _iid_ = Guid('{50ea08b9-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(31)
    def get_isAbstract(self, abstract: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_anyAttribute(self, anyAttribute: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaAny)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_attributes(self, attributes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_contentType(self, contentType: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_contentModel(self, contentModel: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaModelGroup)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_prohibitedSubstitutions(self, prohibited: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaElement(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaParticle
    _iid_ = Guid('{50ea08b7-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(16)
    def get_type(self, type: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_scope(self, scope: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaComplexType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_defaultValue(self, defaultValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_fixedValue(self, fixedValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_isNillable(self, nillable: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_identityConstraints(self, constraints: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_substitutionGroup(self, element: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_substitutionGroupExclusions(self, exclusions: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_disallowedSubstitutions(self, disallowed: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_isAbstract(self, abstract: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_isReference(self, reference: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaIdentityConstraint(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08bd-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_selector(self, selector: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_fields(self, fields: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_referencedKey(self, key: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaIdentityConstraint)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{50ea08b3-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(7)
    def get_name(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_namespaceURI(self, namespaceURI: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_schema(self, schema: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchema)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_id(self, id: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_itemType(self, itemType: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_unhandledAttributes(self, attributes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXAttributes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def writeAnnotation(self, annotationSink: win32more.Windows.Win32.System.Com.IUnknown, isWritten: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaItemCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{50ea08b2-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(7)
    def get_item(self, index: Int32, item: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def itemByName(self, name: win32more.Windows.Win32.Foundation.BSTR, item: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def itemByQName(self, name: win32more.Windows.Win32.Foundation.BSTR, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, item: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_length(self, length: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get__newEnum(self, ppunk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaModelGroup(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaParticle
    _iid_ = Guid('{50ea08bb-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(16)
    def get_particles(self, particles: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaNotation(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08be-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_systemIdentifier(self, uri: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_publicIdentifier(self, uri: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaParticle(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08b5-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_minOccurs(self, minOccurs: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_maxOccurs(self, maxOccurs: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaStringCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{50ea08b1-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(7)
    def get_item(self, index: Int32, bstr: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, length: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__newEnum(self, ppunk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISchemaType(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem
    _iid_ = Guid('{50ea08b8-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def get_baseTypes(self, baseTypes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItemCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_final(self, final: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_variety(self, variety: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_derivedBy(self, derivedBy: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def isValid(self, data: win32more.Windows.Win32.Foundation.BSTR, valid: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_minExclusive(self, minExclusive: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_minInclusive(self, minInclusive: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_maxExclusive(self, maxExclusive: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_maxInclusive(self, maxInclusive: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_totalDigits(self, totalDigits: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_fractionDigits(self, fractionDigits: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_length(self, length: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_minLength(self, minLength: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_maxLength(self, maxLength: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_enumeration(self, enumeration: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_whitespace(self, whitespace: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_patterns(self, patterns: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IServerXMLHTTPRequest(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest
    _iid_ = Guid('{2e9196bf-13ba-4dd4-91ca-6c571f281495}')
    @commethod(21)
    def setTimeouts(self, resolveTimeout: Int32, connectTimeout: Int32, sendTimeout: Int32, receiveTimeout: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def waitForResponse(self, timeoutInSeconds: win32more.Windows.Win32.System.Variant.VARIANT, isSuccessful: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def getOption(self, option: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def setOption(self, option: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION, value: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IServerXMLHTTPRequest2(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IServerXMLHTTPRequest
    _iid_ = Guid('{2e01311b-c322-4b0a-bd77-b90cfdc8dce7}')
    @commethod(25)
    def setProxy(self, proxySetting: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING, varProxyServer: win32more.Windows.Win32.System.Variant.VARIANT, varBypassList: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def setProxyCredentials(self, bstrUserName: win32more.Windows.Win32.Foundation.BSTR, bstrPassword: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBMXNamespaceManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c90352f5-643c-4fbc-bb23-e996eb2d51fd}')
    @commethod(7)
    def put_allowOverride(self, fOverride: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_allowOverride(self, fOverride: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def pushContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def pushNodeContext(self, contextNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, fDeep: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def popContext(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def declarePrefix(self, prefix: win32more.Windows.Win32.Foundation.BSTR, namespaceURI: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def getDeclaredPrefixes(self, prefixes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IMXNamespacePrefixes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def getPrefixes(self, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, prefixes: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IMXNamespacePrefixes)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def getURI(self, prefix: win32more.Windows.Win32.Foundation.BSTR, uri: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def getURIFromNode(self, strPrefix: win32more.Windows.Win32.Foundation.BSTR, contextNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, uri: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXAttributes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{10dc0586-132b-4cac-8bb3-db00ac8b7ee0}')
    @commethod(7)
    def get_length(self, nLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def getURI(self, nIndex: Int32, strURI: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getLocalName(self, nIndex: Int32, strLocalName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getQName(self, nIndex: Int32, strQName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getIndexFromName(self, strURI: win32more.Windows.Win32.Foundation.BSTR, strLocalName: win32more.Windows.Win32.Foundation.BSTR, nIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def getIndexFromQName(self, strQName: win32more.Windows.Win32.Foundation.BSTR, nIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def getType(self, nIndex: Int32, strType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def getTypeFromName(self, strURI: win32more.Windows.Win32.Foundation.BSTR, strLocalName: win32more.Windows.Win32.Foundation.BSTR, strType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def getTypeFromQName(self, strQName: win32more.Windows.Win32.Foundation.BSTR, strType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def getValue(self, nIndex: Int32, strValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def getValueFromName(self, strURI: win32more.Windows.Win32.Foundation.BSTR, strLocalName: win32more.Windows.Win32.Foundation.BSTR, strValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getValueFromQName(self, strQName: win32more.Windows.Win32.Foundation.BSTR, strValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXContentHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2ed7290a-4dd5-4b46-bb26-4e4155e77faa}')
    @commethod(7)
    def putref_documentLocator(self, oLocator: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXLocator) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def startDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def endDocument(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def startPrefixMapping(self, strPrefix: POINTER(win32more.Windows.Win32.Foundation.BSTR), strURI: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def endPrefixMapping(self, strPrefix: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def startElement(self, strNamespaceURI: POINTER(win32more.Windows.Win32.Foundation.BSTR), strLocalName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strQName: POINTER(win32more.Windows.Win32.Foundation.BSTR), oAttributes: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXAttributes) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def endElement(self, strNamespaceURI: POINTER(win32more.Windows.Win32.Foundation.BSTR), strLocalName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strQName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def characters(self, strChars: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ignorableWhitespace(self, strChars: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def processingInstruction(self, strTarget: POINTER(win32more.Windows.Win32.Foundation.BSTR), strData: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def skippedEntity(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXDTDHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{24fb3297-302d-4620-ba39-3a732d850558}')
    @commethod(7)
    def notationDecl(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strPublicId: POINTER(win32more.Windows.Win32.Foundation.BSTR), strSystemId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def unparsedEntityDecl(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strPublicId: POINTER(win32more.Windows.Win32.Foundation.BSTR), strSystemId: POINTER(win32more.Windows.Win32.Foundation.BSTR), strNotationName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXDeclHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{e8917260-7579-4be1-b5dd-7afbfa6f077b}')
    @commethod(7)
    def elementDecl(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strModel: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def attributeDecl(self, strElementName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strAttributeName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strType: POINTER(win32more.Windows.Win32.Foundation.BSTR), strValueDefault: POINTER(win32more.Windows.Win32.Foundation.BSTR), strValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def internalEntityDecl(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def externalEntityDecl(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strPublicId: POINTER(win32more.Windows.Win32.Foundation.BSTR), strSystemId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXEntityResolver(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0c05d096-f45b-4aca-ad1a-aa0bc25518dc}')
    @commethod(7)
    def resolveEntity(self, strPublicId: POINTER(win32more.Windows.Win32.Foundation.BSTR), strSystemId: POINTER(win32more.Windows.Win32.Foundation.BSTR), varInput: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXErrorHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d963d3fe-173c-4862-9095-b92f66995f52}')
    @commethod(7)
    def error(self, oLocator: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXLocator, strErrorMessage: POINTER(win32more.Windows.Win32.Foundation.BSTR), nErrorCode: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def fatalError(self, oLocator: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXLocator, strErrorMessage: POINTER(win32more.Windows.Win32.Foundation.BSTR), nErrorCode: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ignorableWarning(self, oLocator: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXLocator, strErrorMessage: POINTER(win32more.Windows.Win32.Foundation.BSTR), nErrorCode: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXLexicalHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{032aac35-8c0e-4d9d-979f-e3b702935576}')
    @commethod(7)
    def startDTD(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR), strPublicId: POINTER(win32more.Windows.Win32.Foundation.BSTR), strSystemId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def endDTD(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def startEntity(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def endEntity(self, strName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def startCDATA(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def endCDATA(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def comment(self, strChars: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXLocator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{796e7ac5-5aa2-4eff-acad-3faaf01a3288}')
    @commethod(7)
    def get_columnNumber(self, nColumn: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_lineNumber(self, nLine: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_publicId(self, strPublicId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_systemId(self, strSystemId: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXXMLFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{1299eb1b-5b88-433e-82de-82ca75ad4e04}')
    @commethod(7)
    def get_parent(self, oReader: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXXMLReader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def putref_parent(self, oReader: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXXMLReader) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVBSAXXMLReader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{8c033caa-6cd6-4f73-b728-4531af74945f}')
    @commethod(7)
    def getFeature(self, strName: win32more.Windows.Win32.Foundation.BSTR, fValue: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def putFeature(self, strName: win32more.Windows.Win32.Foundation.BSTR, fValue: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getProperty(self, strName: win32more.Windows.Win32.Foundation.BSTR, varValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def putProperty(self, strName: win32more.Windows.Win32.Foundation.BSTR, varValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_entityResolver(self, oResolver: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXEntityResolver)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def putref_entityResolver(self, oResolver: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXEntityResolver) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_contentHandler(self, oHandler: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXContentHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def putref_contentHandler(self, oHandler: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXContentHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_dtdHandler(self, oHandler: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXDTDHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def putref_dtdHandler(self, oHandler: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXDTDHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_errorHandler(self, oHandler: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXErrorHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def putref_errorHandler(self, oHandler: win32more.Windows.Win32.Data.Xml.MsXml.IVBSAXErrorHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_baseURL(self, strBaseURL: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_baseURL(self, strBaseURL: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_secureBaseURL(self, strSecureBaseURL: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_secureBaseURL(self, strSecureBaseURL: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def parse(self, varInput: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def parseURL(self, strURL: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLAttribute(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d4d4a0fc-3b73-11d1-b2b4-00c04fb92596}')
    @commethod(7)
    def get_name(self, n: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_value(self, v: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMAttribute(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf85-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_name(self, attributeName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_value(self, attributeValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_value(self, attributeValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMCDATASection(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMText
    _iid_ = Guid('{2933bf8a-7b36-11d2-b20e-00c04f983e60}')
class IXMLDOMCharacterData(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf84-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_data(self, data: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def put_data(self, data: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_length(self, dataLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def substringData(self, offset: Int32, count: Int32, data: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def appendData(self, data: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def insertData(self, offset: Int32, data: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def deleteData(self, offset: Int32, count: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def replaceData(self, offset: Int32, count: Int32, data: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMComment(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMCharacterData
    _iid_ = Guid('{2933bf88-7b36-11d2-b20e-00c04f983e60}')
class IXMLDOMDocument(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf81-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_doctype(self, documentType: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocumentType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_implementation(self, impl: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMImplementation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_documentElement(self, DOMElement: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def putref_documentElement(self, DOMElement: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def createElement(self, tagName: win32more.Windows.Win32.Foundation.BSTR, element: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def createDocumentFragment(self, docFrag: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocumentFragment)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def createTextNode(self, data: win32more.Windows.Win32.Foundation.BSTR, text: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMText)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def createComment(self, data: win32more.Windows.Win32.Foundation.BSTR, comment: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMComment)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def createCDATASection(self, data: win32more.Windows.Win32.Foundation.BSTR, cdata: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMCDATASection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def createProcessingInstruction(self, target: win32more.Windows.Win32.Foundation.BSTR, data: win32more.Windows.Win32.Foundation.BSTR, pi: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMProcessingInstruction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def createAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, attribute: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def createEntityReference(self, name: win32more.Windows.Win32.Foundation.BSTR, entityRef: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMEntityReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def getElementsByTagName(self, tagName: win32more.Windows.Win32.Foundation.BSTR, resultList: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNodeList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def createNode(self, Type: win32more.Windows.Win32.System.Variant.VARIANT, name: win32more.Windows.Win32.Foundation.BSTR, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, node: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def nodeFromID(self, idString: win32more.Windows.Win32.Foundation.BSTR, node: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def load(self, xmlSource: win32more.Windows.Win32.System.Variant.VARIANT, isSuccessful: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_readyState(self, value: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def get_parseError(self, errorObj: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_url(self, urlString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_async_(self, isAsync: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def put_async_(self, isAsync: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def loadXML(self, bstrXML: win32more.Windows.Win32.Foundation.BSTR, isSuccessful: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def save(self, destination: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def get_validateOnParse(self, isValidating: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def put_validateOnParse(self, isValidating: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def get_resolveExternals(self, isResolving: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def put_resolveExternals(self, isResolving: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def get_preserveWhiteSpace(self, isPreserving: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def put_preserveWhiteSpace(self, isPreserving: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def put_onreadystatechange(self, readystatechangeSink: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def put_ondataavailable(self, ondataavailableSink: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def put_ontransformnode(self, ontransformnodeSink: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMDocument2(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument
    _iid_ = Guid('{2933bf95-7b36-11d2-b20e-00c04f983e60}')
    @commethod(76)
    def get_namespaces(self, namespaceCollection: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMSchemaCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def get_schemas(self, otherCollection: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def putref_schemas(self, otherCollection: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(79)
    def validate(self, errorObj: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def setProperty(self, name: win32more.Windows.Win32.Foundation.BSTR, value: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(81)
    def getProperty(self, name: win32more.Windows.Win32.Foundation.BSTR, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMDocument3(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument2
    _iid_ = Guid('{2933bf96-7b36-11d2-b20e-00c04f983e60}')
    @commethod(82)
    def validateNode(self, node: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, errorObj: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseError)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def importNode(self, node: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, deep: win32more.Windows.Win32.Foundation.VARIANT_BOOL, clone: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMDocumentFragment(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{3efaa413-272f-11d2-836f-0000f87a7782}')
class IXMLDOMDocumentType(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf8b-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_name(self, rootName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_entities(self, entityMap: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNamedNodeMap)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_notations(self, notationMap: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNamedNodeMap)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMElement(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf86-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_tagName(self, tagName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def getAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def setAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR, value: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def removeAttribute(self, name: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def getAttributeNode(self, name: win32more.Windows.Win32.Foundation.BSTR, attributeNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def setAttributeNode(self, DOMAttribute: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMAttribute, attributeNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def removeAttributeNode(self, DOMAttribute: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMAttribute, attributeNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMAttribute)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def getElementsByTagName(self, tagName: win32more.Windows.Win32.Foundation.BSTR, resultList: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNodeList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def normalize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMEntity(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf8d-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_publicId(self, publicID: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_systemId(self, systemID: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_notationName(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMEntityReference(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf8e-7b36-11d2-b20e-00c04f983e60}')
class IXMLDOMImplementation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2933bf8f-7b36-11d2-b20e-00c04f983e60}')
    @commethod(7)
    def hasFeature(self, feature: win32more.Windows.Win32.Foundation.BSTR, version: win32more.Windows.Win32.Foundation.BSTR, hasFeature: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMNamedNodeMap(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2933bf83-7b36-11d2-b20e-00c04f983e60}')
    @commethod(7)
    def getNamedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, namedItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setNamedItem(self, newItem: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, nameItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def removeNamedItem(self, name: win32more.Windows.Win32.Foundation.BSTR, namedItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_item(self, index: Int32, listItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_length(self, listLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def getQualifiedItem(self, baseName: win32more.Windows.Win32.Foundation.BSTR, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, qualifiedItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def removeQualifiedItem(self, baseName: win32more.Windows.Win32.Foundation.BSTR, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, qualifiedItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def nextNode(self, nextItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get__newEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMNode(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2933bf80-7b36-11d2-b20e-00c04f983e60}')
    @commethod(7)
    def get_nodeName(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_nodeValue(self, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def put_nodeValue(self, value: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_nodeType(self, type: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_parentNode(self, parent: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_childNodes(self, childList: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNodeList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_firstChild(self, firstChild: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_lastChild(self, lastChild: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_previousSibling(self, previousSibling: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_nextSibling(self, nextSibling: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_attributes(self, attributeMap: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNamedNodeMap)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def insertBefore(self, newChild: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, refChild: win32more.Windows.Win32.System.Variant.VARIANT, outNewChild: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def replaceChild(self, newChild: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, oldChild: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, outOldChild: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def removeChild(self, childNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, oldChild: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def appendChild(self, newChild: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, outNewChild: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def hasChildNodes(self, hasChild: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_ownerDocument(self, XMLDOMDocument: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def cloneNode(self, deep: win32more.Windows.Win32.Foundation.VARIANT_BOOL, cloneRoot: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_nodeTypeString(self, nodeType: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_text(self, text: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def put_text(self, text: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_specified(self, isSpecified: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_definition(self, definitionNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_nodeTypedValue(self, typedValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_nodeTypedValue(self, typedValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_dataType(self, dataTypeName: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def put_dataType(self, dataTypeName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_xml(self, xmlString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def transformNode(self, stylesheet: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, xmlString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def selectNodes(self, queryString: win32more.Windows.Win32.Foundation.BSTR, resultList: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNodeList)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def selectSingleNode(self, queryString: win32more.Windows.Win32.Foundation.BSTR, resultNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_parsed(self, isParsed: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_namespaceURI(self, namespaceURI: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_prefix(self, prefixString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_baseName(self, nameString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def transformNodeToObject(self, stylesheet: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, outputObject: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMNodeList(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2933bf82-7b36-11d2-b20e-00c04f983e60}')
    @commethod(7)
    def get_item(self, index: Int32, listItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, listLength: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def nextNode(self, nextItem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get__newEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMNotation(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf8c-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_publicId(self, publicID: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_systemId(self, systemID: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMParseError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3efaa426-272f-11d2-836f-0000f87a7782}')
    @commethod(7)
    def get_errorCode(self, errorCode: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_url(self, urlString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_reason(self, reasonString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_srcText(self, sourceString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_line(self, lineNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_linepos(self, linePosition: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_filepos(self, filePosition: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMParseError2(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseError
    _iid_ = Guid('{3efaa428-272f-11d2-836f-0000f87a7782}')
    @commethod(14)
    def get_errorXPath(self, xpathexpr: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_allErrors(self, allErrors: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseErrorCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def errorParameters(self, index: Int32, param1: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_errorParametersCount(self, count: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMParseErrorCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3efaa429-272f-11d2-836f-0000f87a7782}')
    @commethod(7)
    def get_item(self, index: Int32, error: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseError2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, length: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_next(self, error: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMParseError2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get__newEnum(self, ppunk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMProcessingInstruction(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{2933bf89-7b36-11d2-b20e-00c04f983e60}')
    @commethod(43)
    def get_target(self, name: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_data(self, value: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def put_data(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMSchemaCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{373984c8-b845-449b-91e7-45ac83036ade}')
    @commethod(7)
    def add(self, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, var: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get(self, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, schemaNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def remove(self, namespaceURI: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_length(self, length: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_namespaceURI(self, index: Int32, length: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def addCollection(self, otherCollection: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMSchemaCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get__newEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMSchemaCollection2(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMSchemaCollection
    _iid_ = Guid('{50ea08b0-dd1b-4664-9a50-c2f40f4bd79a}')
    @commethod(14)
    def validate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_validateOnLoad(self, validateOnLoad: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_validateOnLoad(self, validateOnLoad: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def getSchema(self, namespaceURI: win32more.Windows.Win32.Foundation.BSTR, schema: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchema)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def getDeclaration(self, node: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, item: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.ISchemaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMSelection(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNodeList
    _iid_ = Guid('{aa634fc7-5888-44a7-a257-3a47150d3a0e}')
    @commethod(12)
    def get_expr(self, expression: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_expr(self, expression: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_context(self, ppNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def putref_context(self, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def peekNode(self, ppNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def matches(self, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, ppNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def removeNext(self, ppNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def removeAll(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def clone(self, ppNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMSelection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def getProperty(self, name: win32more.Windows.Win32.Foundation.BSTR, value: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def setProperty(self, name: win32more.Windows.Win32.Foundation.BSTR, value: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDOMText(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMCharacterData
    _iid_ = Guid('{2933bf87-7b36-11d2-b20e-00c04f983e60}')
    @commethod(51)
    def splitText(self, offset: Int32, rightHandTextNode: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMText)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDSOControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{310afa62-0575-11d2-9ca9-0060b0ec3d39}')
    @commethod(7)
    def get_XMLDocument(self, ppDoc: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_XMLDocument(self, ppDoc: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMDocument) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_JavaDSOCompatible(self, fJavaDSOCompatible: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_JavaDSOCompatible(self, fJavaDSOCompatible: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_readyState(self, state: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDocument(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{f52e2b61-18a1-11d1-b105-00805f49916b}')
    @commethod(7)
    def get_root(self, p: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_fileSize(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_fileModifiedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_fileUpdatedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_URL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_URL(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_mimeType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_readyState(self, pl: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_charset(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_version(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_doctype(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_dtdURL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def createElement(self, vType: win32more.Windows.Win32.System.Variant.VARIANT, var1: win32more.Windows.Win32.System.Variant.VARIANT, ppElem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLDocument2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2b8de2fe-8d2d-11d1-b2fc-00c04fd915a9}')
    @commethod(7)
    def get_root(self, p: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_fileSize(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_fileModifiedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_fileUpdatedDate(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_URL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_URL(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_mimeType(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_readyState(self, pl: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_charset(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_charset(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_version(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_doctype(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_dtdURL(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def createElement(self, vType: win32more.Windows.Win32.System.Variant.VARIANT, var1: win32more.Windows.Win32.System.Variant.VARIANT, ppElem: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_async_(self, pf: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def put_async_(self, f: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLElement(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3f7f31ac-e15f-11d0-9c25-00c04fc99c8e}')
    @commethod(7)
    def get_tagName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_tagName(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_parent(self, ppParent: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def setAttribute(self, strPropertyName: win32more.Windows.Win32.Foundation.BSTR, PropertyValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getAttribute(self, strPropertyName: win32more.Windows.Win32.Foundation.BSTR, PropertyValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def removeAttribute(self, strPropertyName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_children(self, pp: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_type(self, plType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_text(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def addChild(self, pChildElem: win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement, lIndex: Int32, lReserved: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def removeChild(self, pChildElem: win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLElement2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2b8de2ff-8d2d-11d1-b2fc-00c04fd915a9}')
    @commethod(7)
    def get_tagName(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_tagName(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_parent(self, ppParent: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def setAttribute(self, strPropertyName: win32more.Windows.Win32.Foundation.BSTR, PropertyValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def getAttribute(self, strPropertyName: win32more.Windows.Win32.Foundation.BSTR, PropertyValue: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def removeAttribute(self, strPropertyName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_children(self, pp: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_type(self, plType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_text(self, p: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_text(self, p: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def addChild(self, pChildElem: win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement2, lIndex: Int32, lReserved: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def removeChild(self, pChildElem: win32more.Windows.Win32.Data.Xml.MsXml.IXMLElement2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_attributes(self, pp: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLElementCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLElementCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{65725580-9b5d-11d0-9bfe-00c04fc99c8e}')
    @commethod(7)
    def put_length(self, v: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_length(self, p: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__newEnum(self, ppUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def item(self, var1: win32more.Windows.Win32.System.Variant.VARIANT, var2: win32more.Windows.Win32.System.Variant.VARIANT, ppDisp: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLError(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{948c5ad3-c58d-11d0-9c0b-00c04fc99c8e}')
    @commethod(3)
    def GetErrorInfo(self, pErrorReturn: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.XML_ERROR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLHTTPRequest(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{ed8c108d-4349-11d2-91a4-00c04f7969e8}')
    @commethod(7)
    def open(self, bstrMethod: win32more.Windows.Win32.Foundation.BSTR, bstrUrl: win32more.Windows.Win32.Foundation.BSTR, varAsync: win32more.Windows.Win32.System.Variant.VARIANT, bstrUser: win32more.Windows.Win32.System.Variant.VARIANT, bstrPassword: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def setRequestHeader(self, bstrHeader: win32more.Windows.Win32.Foundation.BSTR, bstrValue: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def getResponseHeader(self, bstrHeader: win32more.Windows.Win32.Foundation.BSTR, pbstrValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def getAllResponseHeaders(self, pbstrHeaders: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def send(self, varBody: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_status(self, plStatus: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_statusText(self, pbstrStatus: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_responseXML(self, ppBody: POINTER(win32more.Windows.Win32.System.Com.IDispatch)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_responseText(self, pbstrBody: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_responseBody(self, pvarBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_responseStream(self, pvarBody: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_readyState(self, plState: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_onreadystatechange(self, pReadyStateSink: win32more.Windows.Win32.System.Com.IDispatch) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLHTTPRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e5d37dc0-552a-4d52-9cc0-a14d546fbd04}')
    @commethod(3)
    def Open(self, pwszMethod: win32more.Windows.Win32.Foundation.PWSTR, pwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pStatusCallback: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2Callback, pwszUserName: win32more.Windows.Win32.Foundation.PWSTR, pwszPassword: win32more.Windows.Win32.Foundation.PWSTR, pwszProxyUserName: win32more.Windows.Win32.Foundation.PWSTR, pwszProxyPassword: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Send(self, pBody: win32more.Windows.Win32.System.Com.ISequentialStream, cbBody: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Abort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetCookie(self, pCookie: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE), pdwCookieState: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetCustomResponseStream(self, pSequentialStream: win32more.Windows.Win32.System.Com.ISequentialStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetProperty(self, eProperty: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY, ullValue: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetRequestHeader(self, pwszHeader: win32more.Windows.Win32.Foundation.PWSTR, pwszValue: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetAllResponseHeaders(self, ppwszHeaders: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCookie(self, pwszUrl: win32more.Windows.Win32.Foundation.PWSTR, pwszName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32, pcCookies: POINTER(UInt32), ppCookies: POINTER(POINTER(win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetResponseHeader(self, pwszHeader: win32more.Windows.Win32.Foundation.PWSTR, ppwszValue: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLHTTPRequest2Callback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a44a9299-e321-40de-8866-341b41669162}')
    @commethod(3)
    def OnRedirect(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2, pwszRedirectUrl: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnHeadersAvailable(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2, dwStatus: UInt32, pwszStatus: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnDataAvailable(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2, pResponseStream: win32more.Windows.Win32.System.Com.ISequentialStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def OnResponseReceived(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2, pResponseStream: win32more.Windows.Win32.System.Com.ISequentialStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def OnError(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2, hrError: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLHTTPRequest3(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2
    _iid_ = Guid('{a1c9feee-0617-4f23-9d58-8961ea43567c}')
    @commethod(13)
    def SetClientCertificate(self, cbClientCertificateHash: UInt32, pbClientCertificateHash: POINTER(Byte), pwszPin: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXMLHTTPRequest3Callback(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest2Callback
    _iid_ = Guid('{b9e57830-8c6c-4a6f-9c13-47772bb047bb}')
    @commethod(8)
    def OnServerCertificateReceived(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest3, dwCertificateErrors: UInt32, cServerCertificateChain: UInt32, rgServerCertificateChain: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def OnClientCertificateRequested(self, pXHR: win32more.Windows.Win32.Data.Xml.MsXml.IXMLHTTPRequest3, cIssuerList: UInt32, rgpwszIssuerList: POINTER(POINTER(UInt16))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXSLProcessor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2933bf92-7b36-11d2-b20e-00c04f983e60}')
    @commethod(7)
    def put_input(self, var: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_input(self, pVar: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ownerTemplate(self, ppTemplate: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXSLTemplate)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def setStartMode(self, mode: win32more.Windows.Win32.Foundation.BSTR, namespaceURI: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_startMode(self, mode: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_startModeURI(self, namespaceURI: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_output(self, output: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_output(self, pOutput: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def transform(self, pDone: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_readyState(self, pReadyState: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def addParameter(self, baseName: win32more.Windows.Win32.Foundation.BSTR, parameter: win32more.Windows.Win32.System.Variant.VARIANT, namespaceURI: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def addObject(self, obj: win32more.Windows.Win32.System.Com.IDispatch, namespaceURI: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_stylesheet(self, stylesheet: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXSLTemplate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2933bf93-7b36-11d2-b20e-00c04f983e60}')
    @commethod(7)
    def putref_stylesheet(self, stylesheet: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_stylesheet(self, stylesheet: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def createProcessor(self, ppProcessor: POINTER(win32more.Windows.Win32.Data.Xml.MsXml.IXSLProcessor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXTLRuntime(ComPtr):
    extends: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode
    _iid_ = Guid('{3efaa425-272f-11d2-836f-0000f87a7782}')
    @commethod(43)
    def uniqueID(self, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, pID: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def depth(self, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, pDepth: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def childNumber(self, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, pNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def ancestorChildNumber(self, bstrNodeName: win32more.Windows.Win32.Foundation.BSTR, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, pNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def absoluteChildNumber(self, pNode: win32more.Windows.Win32.Data.Xml.MsXml.IXMLDOMNode, pNumber: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def formatIndex(self, lIndex: Int32, bstrFormat: win32more.Windows.Win32.Foundation.BSTR, pbstrFormattedString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def formatNumber(self, dblNumber: Double, bstrFormat: win32more.Windows.Win32.Foundation.BSTR, pbstrFormattedString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def formatDate(self, varDate: win32more.Windows.Win32.System.Variant.VARIANT, bstrFormat: win32more.Windows.Win32.Foundation.BSTR, varDestLocale: win32more.Windows.Win32.System.Variant.VARIANT, pbstrFormattedString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def formatTime(self, varTime: win32more.Windows.Win32.System.Variant.VARIANT, bstrFormat: win32more.Windows.Win32.Foundation.BSTR, varDestLocale: win32more.Windows.Win32.System.Variant.VARIANT, pbstrFormattedString: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
MXHTMLWriter60 = Guid('{88d96a10-f192-11d4-a65f-0040963251e5}')
MXNamespaceManager60 = Guid('{88d96a11-f192-11d4-a65f-0040963251e5}')
MXXMLWriter60 = Guid('{88d96a0f-f192-11d4-a65f-0040963251e5}')
SAXAttributes60 = Guid('{88d96a0e-f192-11d4-a65f-0040963251e5}')
SAXXMLReader60 = Guid('{88d96a0c-f192-11d4-a65f-0040963251e5}')
SCHEMACONTENTTYPE = Int32
SCHEMACONTENTTYPE_EMPTY: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE = 0
SCHEMACONTENTTYPE_TEXTONLY: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE = 1
SCHEMACONTENTTYPE_ELEMENTONLY: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE = 2
SCHEMACONTENTTYPE_MIXED: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE = 3
SCHEMADERIVATIONMETHOD = Int32
SCHEMADERIVATIONMETHOD_EMPTY: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 0
SCHEMADERIVATIONMETHOD_SUBSTITUTION: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 1
SCHEMADERIVATIONMETHOD_EXTENSION: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 2
SCHEMADERIVATIONMETHOD_RESTRICTION: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 4
SCHEMADERIVATIONMETHOD_LIST: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 8
SCHEMADERIVATIONMETHOD_UNION: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 16
SCHEMADERIVATIONMETHOD_ALL: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 255
SCHEMADERIVATIONMETHOD_NONE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD = 256
SCHEMAPROCESSCONTENTS = Int32
SCHEMAPROCESSCONTENTS_NONE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS = 0
SCHEMAPROCESSCONTENTS_SKIP: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS = 1
SCHEMAPROCESSCONTENTS_LAX: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS = 2
SCHEMAPROCESSCONTENTS_STRICT: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS = 3
SCHEMATYPEVARIETY = Int32
SCHEMATYPEVARIETY_NONE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY = -1
SCHEMATYPEVARIETY_ATOMIC: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY = 0
SCHEMATYPEVARIETY_LIST: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY = 1
SCHEMATYPEVARIETY_UNION: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY = 2
SCHEMAUSE = Int32
SCHEMAUSE_OPTIONAL: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAUSE = 0
SCHEMAUSE_PROHIBITED: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAUSE = 1
SCHEMAUSE_REQUIRED: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAUSE = 2
SCHEMAWHITESPACE = Int32
SCHEMAWHITESPACE_NONE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE = -1
SCHEMAWHITESPACE_PRESERVE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE = 0
SCHEMAWHITESPACE_REPLACE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE = 1
SCHEMAWHITESPACE_COLLAPSE: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE = 2
SERVERXMLHTTP_OPTION = Int32
SXH_OPTION_URL: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION = -1
SXH_OPTION_URL_CODEPAGE: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION = 0
SXH_OPTION_ESCAPE_PERCENT_IN_URL: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION = 1
SXH_OPTION_IGNORE_SERVER_SSL_CERT_ERROR_FLAGS: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION = 2
SXH_OPTION_SELECT_CLIENT_SSL_CERT: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION = 3
SOMITEMTYPE = Int32
SOMITEM_SCHEMA: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4096
SOMITEM_ATTRIBUTE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4097
SOMITEM_ATTRIBUTEGROUP: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4098
SOMITEM_NOTATION: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4099
SOMITEM_ANNOTATION: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4100
SOMITEM_IDENTITYCONSTRAINT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4352
SOMITEM_KEY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4353
SOMITEM_KEYREF: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4354
SOMITEM_UNIQUE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 4355
SOMITEM_ANYTYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8192
SOMITEM_DATATYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8448
SOMITEM_DATATYPE_ANYTYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8449
SOMITEM_DATATYPE_ANYURI: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8450
SOMITEM_DATATYPE_BASE64BINARY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8451
SOMITEM_DATATYPE_BOOLEAN: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8452
SOMITEM_DATATYPE_BYTE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8453
SOMITEM_DATATYPE_DATE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8454
SOMITEM_DATATYPE_DATETIME: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8455
SOMITEM_DATATYPE_DAY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8456
SOMITEM_DATATYPE_DECIMAL: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8457
SOMITEM_DATATYPE_DOUBLE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8458
SOMITEM_DATATYPE_DURATION: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8459
SOMITEM_DATATYPE_ENTITIES: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8460
SOMITEM_DATATYPE_ENTITY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8461
SOMITEM_DATATYPE_FLOAT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8462
SOMITEM_DATATYPE_HEXBINARY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8463
SOMITEM_DATATYPE_ID: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8464
SOMITEM_DATATYPE_IDREF: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8465
SOMITEM_DATATYPE_IDREFS: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8466
SOMITEM_DATATYPE_INT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8467
SOMITEM_DATATYPE_INTEGER: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8468
SOMITEM_DATATYPE_LANGUAGE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8469
SOMITEM_DATATYPE_LONG: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8470
SOMITEM_DATATYPE_MONTH: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8471
SOMITEM_DATATYPE_MONTHDAY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8472
SOMITEM_DATATYPE_NAME: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8473
SOMITEM_DATATYPE_NCNAME: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8474
SOMITEM_DATATYPE_NEGATIVEINTEGER: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8475
SOMITEM_DATATYPE_NMTOKEN: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8476
SOMITEM_DATATYPE_NMTOKENS: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8477
SOMITEM_DATATYPE_NONNEGATIVEINTEGER: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8478
SOMITEM_DATATYPE_NONPOSITIVEINTEGER: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8479
SOMITEM_DATATYPE_NORMALIZEDSTRING: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8480
SOMITEM_DATATYPE_NOTATION: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8481
SOMITEM_DATATYPE_POSITIVEINTEGER: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8482
SOMITEM_DATATYPE_QNAME: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8483
SOMITEM_DATATYPE_SHORT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8484
SOMITEM_DATATYPE_STRING: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8485
SOMITEM_DATATYPE_TIME: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8486
SOMITEM_DATATYPE_TOKEN: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8487
SOMITEM_DATATYPE_UNSIGNEDBYTE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8488
SOMITEM_DATATYPE_UNSIGNEDINT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8489
SOMITEM_DATATYPE_UNSIGNEDLONG: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8490
SOMITEM_DATATYPE_UNSIGNEDSHORT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8491
SOMITEM_DATATYPE_YEAR: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8492
SOMITEM_DATATYPE_YEARMONTH: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8493
SOMITEM_DATATYPE_ANYSIMPLETYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8703
SOMITEM_SIMPLETYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 8704
SOMITEM_COMPLEXTYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 9216
SOMITEM_PARTICLE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16384
SOMITEM_ANY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16385
SOMITEM_ANYATTRIBUTE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16386
SOMITEM_ELEMENT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16387
SOMITEM_GROUP: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16640
SOMITEM_ALL: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16641
SOMITEM_CHOICE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16642
SOMITEM_SEQUENCE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16643
SOMITEM_EMPTYPARTICLE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 16644
SOMITEM_NULL: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 2048
SOMITEM_NULL_TYPE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 10240
SOMITEM_NULL_ANY: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 18433
SOMITEM_NULL_ANYATTRIBUTE: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 18434
SOMITEM_NULL_ELEMENT: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE = 18435
SXH_PROXY_SETTING = Int32
SXH_PROXY_SET_DEFAULT: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING = 0
SXH_PROXY_SET_PRECONFIG: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING = 0
SXH_PROXY_SET_DIRECT: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING = 1
SXH_PROXY_SET_PROXY: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING = 2
SXH_SERVER_CERT_OPTION = Int32
SXH_SERVER_CERT_IGNORE_UNKNOWN_CA: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION = 256
SXH_SERVER_CERT_IGNORE_WRONG_USAGE: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION = 512
SXH_SERVER_CERT_IGNORE_CERT_CN_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION = 4096
SXH_SERVER_CERT_IGNORE_CERT_DATE_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION = 8192
SXH_SERVER_CERT_IGNORE_ALL_SERVER_ERRORS: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION = 13056
ServerXMLHTTP60 = Guid('{88d96a0b-f192-11d4-a65f-0040963251e5}')
XHR_AUTH = Int32
XHR_AUTH_ALL: win32more.Windows.Win32.Data.Xml.MsXml.XHR_AUTH = 0
XHR_AUTH_NONE: win32more.Windows.Win32.Data.Xml.MsXml.XHR_AUTH = 1
XHR_AUTH_PROXY: win32more.Windows.Win32.Data.Xml.MsXml.XHR_AUTH = 2
class XHR_CERT(Structure):
    cbCert: UInt32
    pbCert: POINTER(Byte)
XHR_CERT_ERROR_FLAG = UInt32
XHR_CERT_ERROR_REVOCATION_FAILED: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_ERROR_FLAG = 8388608
XHR_CERT_ERROR_UNKNOWN_CA: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_ERROR_FLAG = 16777216
XHR_CERT_ERROR_CERT_CN_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_ERROR_FLAG = 33554432
XHR_CERT_ERROR_CERT_DATE_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_ERROR_FLAG = 67108864
XHR_CERT_ERROR_ALL_SERVER_ERRORS: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_ERROR_FLAG = 125829120
XHR_CERT_IGNORE_FLAG = UInt32
XHR_CERT_IGNORE_REVOCATION_FAILED: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_IGNORE_FLAG = 128
XHR_CERT_IGNORE_UNKNOWN_CA: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_IGNORE_FLAG = 256
XHR_CERT_IGNORE_CERT_CN_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_IGNORE_FLAG = 4096
XHR_CERT_IGNORE_CERT_DATE_INVALID: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_IGNORE_FLAG = 8192
XHR_CERT_IGNORE_ALL_SERVER_ERRORS: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CERT_IGNORE_FLAG = 12672
class XHR_COOKIE(Structure):
    pwszUrl: win32more.Windows.Win32.Foundation.PWSTR
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pwszValue: win32more.Windows.Win32.Foundation.PWSTR
    pwszP3PPolicy: win32more.Windows.Win32.Foundation.PWSTR
    ftExpires: win32more.Windows.Win32.Foundation.FILETIME
    dwFlags: UInt32
XHR_COOKIE_FLAG = Int32
XHR_COOKIE_IS_SECURE: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 1
XHR_COOKIE_IS_SESSION: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 2
XHR_COOKIE_THIRD_PARTY: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 16
XHR_COOKIE_PROMPT_REQUIRED: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 32
XHR_COOKIE_EVALUATE_P3P: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 64
XHR_COOKIE_APPLY_P3P: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 128
XHR_COOKIE_P3P_ENABLED: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 256
XHR_COOKIE_IS_RESTRICTED: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 512
XHR_COOKIE_IE6: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 1024
XHR_COOKIE_IS_LEGACY: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 2048
XHR_COOKIE_NON_SCRIPT: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 4096
XHR_COOKIE_HTTPONLY: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_FLAG = 8192
XHR_COOKIE_STATE = Int32
XHR_COOKIE_STATE_UNKNOWN: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_STATE = 0
XHR_COOKIE_STATE_ACCEPT: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_STATE = 1
XHR_COOKIE_STATE_PROMPT: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_STATE = 2
XHR_COOKIE_STATE_LEASH: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_STATE = 3
XHR_COOKIE_STATE_DOWNGRADE: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_STATE = 4
XHR_COOKIE_STATE_REJECT: win32more.Windows.Win32.Data.Xml.MsXml.XHR_COOKIE_STATE = 5
XHR_CRED_PROMPT = Int32
XHR_CRED_PROMPT_ALL: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CRED_PROMPT = 0
XHR_CRED_PROMPT_NONE: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CRED_PROMPT = 1
XHR_CRED_PROMPT_PROXY: win32more.Windows.Win32.Data.Xml.MsXml.XHR_CRED_PROMPT = 2
XHR_PROPERTY = Int32
XHR_PROP_NO_CRED_PROMPT: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 0
XHR_PROP_NO_AUTH: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 1
XHR_PROP_TIMEOUT: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 2
XHR_PROP_NO_DEFAULT_HEADERS: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 3
XHR_PROP_REPORT_REDIRECT_STATUS: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 4
XHR_PROP_NO_CACHE: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 5
XHR_PROP_EXTENDED_ERROR: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 6
XHR_PROP_QUERY_STRING_UTF8: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 7
XHR_PROP_IGNORE_CERT_ERRORS: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 8
XHR_PROP_ONDATA_THRESHOLD: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 9
XHR_PROP_SET_ENTERPRISEID: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 10
XHR_PROP_MAX_CONNECTIONS: win32more.Windows.Win32.Data.Xml.MsXml.XHR_PROPERTY = 11
class XMLDOMDocumentEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3efaa427-272f-11d2-836f-0000f87a7782}')
XMLDSOControl = Guid('{550dda30-0541-11d2-9ca9-0060b0ec3d39}')
XMLDocument = Guid('{cfc399af-d876-11d0-9c10-00c04fc99c8e}')
XMLELEM_TYPE = Int32
XMLELEMTYPE_ELEMENT: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 0
XMLELEMTYPE_TEXT: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 1
XMLELEMTYPE_COMMENT: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 2
XMLELEMTYPE_DOCUMENT: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 3
XMLELEMTYPE_DTD: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 4
XMLELEMTYPE_PI: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 5
XMLELEMTYPE_OTHER: win32more.Windows.Win32.Data.Xml.MsXml.XMLELEM_TYPE = 6
XMLHTTP60 = Guid('{88d96a0a-f192-11d4-a65f-0040963251e5}')
XMLHTTPRequest = Guid('{ed8c108e-4349-11d2-91a4-00c04f7969e8}')
XMLSchemaCache60 = Guid('{88d96a07-f192-11d4-a65f-0040963251e5}')
class XML_ERROR(Structure):
    _nLine: UInt32
    _pchBuf: win32more.Windows.Win32.Foundation.BSTR
    _cchBuf: UInt32
    _ich: UInt32
    _pszFound: win32more.Windows.Win32.Foundation.BSTR
    _pszExpected: win32more.Windows.Win32.Foundation.BSTR
    _reserved1: UInt32
    _reserved2: UInt32
XSLTemplate60 = Guid('{88d96a08-f192-11d4-a65f-0040963251e5}')
class __msxml6_ReferenceRemainingTypes__(Structure):
    __tagDomNodeType__: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType
    __domNodeType__: win32more.Windows.Win32.Data.Xml.MsXml.DOMNodeType
    __serverXmlHttpOptionEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION
    __serverXmlHttpOption__: win32more.Windows.Win32.Data.Xml.MsXml.SERVERXMLHTTP_OPTION
    __serverCertOptionEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION
    __serverCertOption__: win32more.Windows.Win32.Data.Xml.MsXml.SXH_SERVER_CERT_OPTION
    __proxySettingEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING
    __proxySetting__: win32more.Windows.Win32.Data.Xml.MsXml.SXH_PROXY_SETTING
    __somItemTypeEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE
    __somItemType__: win32more.Windows.Win32.Data.Xml.MsXml.SOMITEMTYPE
    __schemaUseEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAUSE
    __schemaUse__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAUSE
    __schemaDerivationMethodEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD
    __schemaDerivationMethod__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMADERIVATIONMETHOD
    __schemaContentTypeEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE
    __schemaContentType__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMACONTENTTYPE
    __schemaProcessContentsEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS
    __schemaProcessContents__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAPROCESSCONTENTS
    __schemaWhitespaceEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE
    __schemaWhitespace__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMAWHITESPACE
    __schemaTypeVarietyEnum__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY
    __schemaTypeVariety__: win32more.Windows.Win32.Data.Xml.MsXml.SCHEMATYPEVARIETY


make_ready(__name__)
